type token =
  | IDENT of (string * Cabs.cabsloc)
  | CST_CHAR of (int64 list * Cabs.cabsloc)
  | CST_WCHAR of (int64 list * Cabs.cabsloc)
  | CST_INT of (string * Cabs.cabsloc)
  | CST_FLOAT of (string * Cabs.cabsloc)
  | NAMED_TYPE of (string * Cabs.cabsloc)
  | CST_STRING of (int64 list * Cabs.cabsloc)
  | CST_WSTRING of (int64 list * Cabs.cabsloc)
  | EOF
  | CHAR of (Cabs.cabsloc)
  | INT of (Cabs.cabsloc)
  | DOUBLE of (Cabs.cabsloc)
  | FLOAT of (Cabs.cabsloc)
  | VOID of (Cabs.cabsloc)
  | INT64 of (Cabs.cabsloc)
  | INT32 of (Cabs.cabsloc)
  | ENUM of (Cabs.cabsloc)
  | STRUCT of (Cabs.cabsloc)
  | TYPEDEF of (Cabs.cabsloc)
  | UNION of (Cabs.cabsloc)
  | SIGNED of (Cabs.cabsloc)
  | UNSIGNED of (Cabs.cabsloc)
  | LONG of (Cabs.cabsloc)
  | SHORT of (Cabs.cabsloc)
  | VOLATILE of (Cabs.cabsloc)
  | EXTERN of (Cabs.cabsloc)
  | STATIC of (Cabs.cabsloc)
  | CONST of (Cabs.cabsloc)
  | RESTRICT of (Cabs.cabsloc)
  | AUTO of (Cabs.cabsloc)
  | REGISTER of (Cabs.cabsloc)
  | THREAD of (Cabs.cabsloc)
  | SIZEOF of (Cabs.cabsloc)
  | ALIGNOF of (Cabs.cabsloc)
  | EQ
  | PLUS_EQ
  | MINUS_EQ
  | STAR_EQ
  | SLASH_EQ
  | PERCENT_EQ
  | AND_EQ
  | PIPE_EQ
  | CIRC_EQ
  | INF_INF_EQ
  | SUP_SUP_EQ
  | ARROW
  | DOT
  | EQ_EQ
  | EXCLAM_EQ
  | INF
  | SUP
  | INF_EQ
  | SUP_EQ
  | PLUS of (Cabs.cabsloc)
  | MINUS of (Cabs.cabsloc)
  | STAR of (Cabs.cabsloc)
  | SLASH
  | PERCENT
  | TILDE of (Cabs.cabsloc)
  | AND of (Cabs.cabsloc)
  | PIPE
  | CIRC
  | EXCLAM of (Cabs.cabsloc)
  | AND_AND of (Cabs.cabsloc)
  | PIPE_PIPE
  | INF_INF
  | SUP_SUP
  | PLUS_PLUS of (Cabs.cabsloc)
  | MINUS_MINUS of (Cabs.cabsloc)
  | RPAREN
  | LPAREN of (Cabs.cabsloc)
  | RBRACE of (Cabs.cabsloc)
  | LBRACE of (Cabs.cabsloc)
  | LBRACKET
  | RBRACKET
  | COLON
  | SEMICOLON of (Cabs.cabsloc)
  | COMMA
  | ELLIPSIS
  | QUEST
  | BREAK of (Cabs.cabsloc)
  | CONTINUE of (Cabs.cabsloc)
  | GOTO of (Cabs.cabsloc)
  | RETURN of (Cabs.cabsloc)
  | SWITCH of (Cabs.cabsloc)
  | CASE of (Cabs.cabsloc)
  | DEFAULT of (Cabs.cabsloc)
  | WHILE of (Cabs.cabsloc)
  | DO of (Cabs.cabsloc)
  | FOR of (Cabs.cabsloc)
  | IF of (Cabs.cabsloc)
  | TRY of (Cabs.cabsloc)
  | EXCEPT of (Cabs.cabsloc)
  | FINALLY of (Cabs.cabsloc)
  | ELSE
  | ATTRIBUTE of (Cabs.cabsloc)
  | INLINE of (Cabs.cabsloc)
  | ASM of (Cabs.cabsloc)
  | TYPEOF of (Cabs.cabsloc)
  | FUNCTION__ of (Cabs.cabsloc)
  | PRETTY_FUNCTION__ of (Cabs.cabsloc)
  | LABEL__
  | BUILTIN_VA_ARG of (Cabs.cabsloc)
  | ATTRIBUTE_USED of (Cabs.cabsloc)
  | BUILTIN_VA_LIST
  | BLOCKATTRIBUTE
  | BUILTIN_TYPES_COMPAT of (Cabs.cabsloc)
  | BUILTIN_OFFSETOF of (Cabs.cabsloc)
  | DECLSPEC of (Cabs.cabsloc)
  | MSASM of (string * Cabs.cabsloc)
  | MSATTR of (string * Cabs.cabsloc)
  | PRAGMA of (Cabs.cabsloc)
  | PRAGMA_LINE of (string * Cabs.cabsloc)
  | PRAGMA_EOL
  | AT_TRANSFORM of (Cabs.cabsloc)
  | AT_TRANSFORMEXPR of (Cabs.cabsloc)
  | AT_SPECIFIER of (Cabs.cabsloc)
  | AT_EXPR of (Cabs.cabsloc)
  | AT_NAME

open Parsing;;
# 44 "src/frontc/cparser.mly"
open Cabs
module E = Errormsg

let parse_error msg : unit =       (* sm: c++-mode highlight hack: -> ' <- *)
  E.parse_error msg

let print = print_string


let currentLoc () = 
  let l, f, c = E.getPosition () in
  { lineno   = l; filename = f; byteno   = c; }

let cabslu = {lineno = -10; filename = "cabs loc unknown"; byteno = -10;}

(*
** Expression building
*)
let smooth_expression lst =
  match lst with
    [] -> NOTHING
  | [expr] -> expr
  | _ -> COMMA (lst)


let currentFunctionName = ref "<outside any function>"
    
let announceFunctionName ((n, decl, _, _):name) =
  !Lexerhack.add_identifier n;
  (* Start a context that includes the parameter names and the whole body. 
   * Will pop when we finish parsing the function body *)
  !Lexerhack.push_context ();
  (* Go through all the parameter names and mark them as identifiers *)
  let rec findProto = function
      PROTO (d, args, _) when isJUSTBASE d -> 
        List.iter (fun (_, (an, _, _, _)) -> !Lexerhack.add_identifier an) args

    | PROTO (d, _, _) -> findProto d
    | PARENTYPE (_, d, _) -> findProto d
    | PTR (_, d) -> findProto d
    | ARRAY (d, _, _) -> findProto d
    | _ -> parse_error "Cannot find the prototype in a function definition";
           raise Parsing.Parse_error 

  and isJUSTBASE = function
      JUSTBASE -> true
    | PARENTYPE (_, d, _) -> isJUSTBASE d
    | _ -> false
  in
  findProto decl;
  currentFunctionName := n



let applyPointer (ptspecs: attribute list list) (dt: decl_type)  
       : decl_type = 
  (* Outer specification first *)
  let rec loop = function
      [] -> dt
    | attrs :: rest -> PTR(attrs, loop rest)
  in
  loop ptspecs

let doDeclaration (loc: cabsloc) (specs: spec_elem list) (nl: init_name list) : definition = 
  if isTypedef specs then begin
    (* Tell the lexer about the new type names *)
    List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_type n) nl;
    TYPEDEF ((specs, List.map (fun (n, _) -> n) nl), loc)
  end else
    if nl = [] then
      ONLYTYPEDEF (specs, loc)
    else begin
      (* Tell the lexer about the new variable names *)
      List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_identifier n) nl;
      DECDEF ((specs, nl), loc)  
    end


let doFunctionDef (loc: cabsloc)
                  (lend: cabsloc)
                  (specs: spec_elem list) 
                  (n: name) 
                  (b: block) : definition = 
  let fname = (specs, n) in
  FUNDEF (fname, b, loc, lend)


let doOldParDecl (names: string list)
                 ((pardefs: name_group list), (isva: bool)) 
    : single_name list * bool =
  let findOneName n =
    (* Search in pardefs for the definition for this parameter *)
    let rec loopGroups = function
        [] -> ([SpecType Tint], (n, JUSTBASE, [], cabslu))
      | (specs, names) :: restgroups ->
          let rec loopNames = function
              [] -> loopGroups restgroups
            | ((n',_, _, _) as sn) :: _ when n' = n -> (specs, sn)
            | _ :: restnames -> loopNames restnames
          in
          loopNames names
    in
    loopGroups pardefs
  in
  let args = List.map findOneName names in
  (args, isva)

let checkConnective (s : string) : unit =
begin
  (* checking this means I could possibly have more connectives, with *)
  (* different meaning *)
  if (s <> "to") then (
    parse_error "transformer connective must be 'to'";
    raise Parsing.Parse_error
  )
  else ()
end

let int64_to_char value =
  if (compare value (Int64.of_int 255) > 0) || (compare value Int64.zero < 0) then
    begin
      let msg = Printf.sprintf "cparser:intlist_to_string: character 0x%Lx too big" value in
      parse_error msg;
      raise Parsing.Parse_error
    end
  else
    Char.chr (Int64.to_int value)

(* takes a not-nul-terminated list, and converts it to a string. *)
let rec intlist_to_string (str: int64 list):string =
  match str with
    [] -> ""  (* add nul-termination *)
  | value::rest ->
      let this_char = int64_to_char value in
      (String.make 1 this_char) ^ (intlist_to_string rest)

let fst3 (result, _, _) = result
let snd3 (_, result, _) = result
let trd3 (_, _, result) = result


(*
   transform:  __builtin_offsetof(type, member)
   into     :  (size_t) (&(type * ) 0)->member
 *)

let transformOffsetOf (speclist, dtype) member =
  let rec addPointer = function
    | JUSTBASE ->
	PTR([], JUSTBASE)
    | PARENTYPE (attrs1, dtype, attrs2) ->
	PARENTYPE (attrs1, addPointer dtype, attrs2)
    | ARRAY (dtype, attrs, expr) ->
	ARRAY (addPointer dtype, attrs, expr)
    | PTR (attrs, dtype) ->
	PTR (attrs, addPointer dtype)
    | PROTO (dtype, names, variadic) ->
	PROTO (addPointer dtype, names, variadic)
  in
  let nullType = (speclist, addPointer dtype) in
  let nullExpr = CONSTANT (CONST_INT "0") in
  let castExpr = CAST (nullType, SINGLE_INIT nullExpr) in

  let rec replaceBase = function
    | VARIABLE field ->
	MEMBEROFPTR (castExpr, field)
    | MEMBEROF (base, field) ->
	MEMBEROF (replaceBase base, field)
    | INDEX (base, index) ->
	INDEX (replaceBase base, index)
    | _ ->
	parse_error "malformed offset expression in __builtin_offsetof";
        raise Parsing.Parse_error 
  in
  let memberExpr = replaceBase member in
  let addrExpr = UNARY (ADDROF, memberExpr) in
  (* slight cheat: hard-coded assumption that size_t == unsigned int *)
  let sizeofType = [SpecType Tunsigned], JUSTBASE in
  let resultExpr = CAST (sizeofType, SINGLE_INIT addrExpr) in
  resultExpr

# 306 "src/frontc/cparser.ml"
let yytransl_const = [|
    0 (* EOF *);
  290 (* EQ *);
  291 (* PLUS_EQ *);
  292 (* MINUS_EQ *);
  293 (* STAR_EQ *);
  294 (* SLASH_EQ *);
  295 (* PERCENT_EQ *);
  296 (* AND_EQ *);
  297 (* PIPE_EQ *);
  298 (* CIRC_EQ *);
  299 (* INF_INF_EQ *);
  300 (* SUP_SUP_EQ *);
  301 (* ARROW *);
  302 (* DOT *);
  303 (* EQ_EQ *);
  304 (* EXCLAM_EQ *);
  305 (* INF *);
  306 (* SUP *);
  307 (* INF_EQ *);
  308 (* SUP_EQ *);
  312 (* SLASH *);
  313 (* PERCENT *);
  316 (* PIPE *);
  317 (* CIRC *);
  320 (* PIPE_PIPE *);
  321 (* INF_INF *);
  322 (* SUP_SUP *);
  325 (* RPAREN *);
  329 (* LBRACKET *);
  330 (* RBRACKET *);
  331 (* COLON *);
  333 (* COMMA *);
  334 (* ELLIPSIS *);
  335 (* QUEST *);
  350 (* ELSE *);
  357 (* LABEL__ *);
  360 (* BUILTIN_VA_LIST *);
  361 (* BLOCKATTRIBUTE *);
  369 (* PRAGMA_EOL *);
  374 (* AT_NAME *);
    0|]

let yytransl_block = [|
  257 (* IDENT *);
  258 (* CST_CHAR *);
  259 (* CST_WCHAR *);
  260 (* CST_INT *);
  261 (* CST_FLOAT *);
  262 (* NAMED_TYPE *);
  263 (* CST_STRING *);
  264 (* CST_WSTRING *);
  265 (* CHAR *);
  266 (* INT *);
  267 (* DOUBLE *);
  268 (* FLOAT *);
  269 (* VOID *);
  270 (* INT64 *);
  271 (* INT32 *);
  272 (* ENUM *);
  273 (* STRUCT *);
  274 (* TYPEDEF *);
  275 (* UNION *);
  276 (* SIGNED *);
  277 (* UNSIGNED *);
  278 (* LONG *);
  279 (* SHORT *);
  280 (* VOLATILE *);
  281 (* EXTERN *);
  282 (* STATIC *);
  283 (* CONST *);
  284 (* RESTRICT *);
  285 (* AUTO *);
  286 (* REGISTER *);
  287 (* THREAD *);
  288 (* SIZEOF *);
  289 (* ALIGNOF *);
  309 (* PLUS *);
  310 (* MINUS *);
  311 (* STAR *);
  314 (* TILDE *);
  315 (* AND *);
  318 (* EXCLAM *);
  319 (* AND_AND *);
  323 (* PLUS_PLUS *);
  324 (* MINUS_MINUS *);
  326 (* LPAREN *);
  327 (* RBRACE *);
  328 (* LBRACE *);
  332 (* SEMICOLON *);
  336 (* BREAK *);
  337 (* CONTINUE *);
  338 (* GOTO *);
  339 (* RETURN *);
  340 (* SWITCH *);
  341 (* CASE *);
  342 (* DEFAULT *);
  343 (* WHILE *);
  344 (* DO *);
  345 (* FOR *);
  346 (* IF *);
  347 (* TRY *);
  348 (* EXCEPT *);
  349 (* FINALLY *);
  351 (* ATTRIBUTE *);
  352 (* INLINE *);
  353 (* ASM *);
  354 (* TYPEOF *);
  355 (* FUNCTION__ *);
  356 (* PRETTY_FUNCTION__ *);
  358 (* BUILTIN_VA_ARG *);
  359 (* ATTRIBUTE_USED *);
  362 (* BUILTIN_TYPES_COMPAT *);
  363 (* BUILTIN_OFFSETOF *);
  364 (* DECLSPEC *);
  365 (* MSASM *);
  366 (* MSATTR *);
  367 (* PRAGMA *);
  368 (* PRAGMA_LINE *);
  370 (* AT_TRANSFORM *);
  371 (* AT_TRANSFORMEXPR *);
  372 (* AT_SPECIFIER *);
  373 (* AT_EXPR *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\003\000\003\000\003\000\051\000\004\000\004\000\
\004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
\004\000\004\000\004\000\055\000\055\000\055\000\056\000\056\000\
\057\000\057\000\057\000\057\000\057\000\058\000\058\000\058\000\
\058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
\059\000\059\000\059\000\061\000\061\000\061\000\061\000\061\000\
\061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
\061\000\062\000\062\000\063\000\063\000\063\000\063\000\064\000\
\064\000\064\000\065\000\065\000\065\000\066\000\066\000\066\000\
\066\000\066\000\067\000\067\000\067\000\068\000\068\000\069\000\
\069\000\070\000\070\000\071\000\071\000\072\000\072\000\073\000\
\073\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
\074\000\074\000\074\000\074\000\074\000\011\000\009\000\009\000\
\009\000\009\000\009\000\009\000\010\000\075\000\018\000\018\000\
\019\000\019\000\019\000\076\000\076\000\076\000\013\000\013\000\
\021\000\021\000\060\000\060\000\020\000\020\000\020\000\077\000\
\077\000\022\000\022\000\022\000\023\000\023\000\078\000\016\000\
\016\000\012\000\012\000\014\000\014\000\014\000\079\000\079\000\
\015\000\015\000\017\000\017\000\035\000\035\000\080\000\081\000\
\081\000\036\000\036\000\036\000\036\000\037\000\037\000\038\000\
\038\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\008\000\083\000\083\000\031\000\031\000\041\000\041\000\040\000\
\040\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\024\000\086\000\086\000\087\000\087\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\026\000\026\000\026\000\026\000\026\000\
\044\000\044\000\043\000\043\000\043\000\030\000\030\000\030\000\
\029\000\029\000\042\000\045\000\045\000\045\000\045\000\045\000\
\090\000\091\000\091\000\092\000\092\000\092\000\028\000\028\000\
\028\000\028\000\027\000\093\000\093\000\039\000\039\000\054\000\
\054\000\054\000\094\000\094\000\094\000\049\000\050\000\050\000\
\034\000\034\000\048\000\048\000\046\000\046\000\046\000\046\000\
\047\000\047\000\032\000\033\000\033\000\033\000\033\000\033\000\
\052\000\052\000\052\000\005\000\005\000\006\000\006\000\006\000\
\088\000\088\000\088\000\088\000\095\000\095\000\095\000\095\000\
\096\000\096\000\089\000\089\000\097\000\097\000\097\000\097\000\
\097\000\097\000\097\000\097\000\097\000\097\000\097\000\098\000\
\098\000\098\000\098\000\098\000\099\000\099\000\099\000\099\000\
\099\000\099\000\099\000\099\000\099\000\099\000\099\000\100\000\
\101\000\101\000\101\000\101\000\102\000\102\000\102\000\103\000\
\103\000\103\000\104\000\104\000\104\000\104\000\104\000\105\000\
\105\000\105\000\106\000\106\000\107\000\107\000\108\000\108\000\
\109\000\109\000\110\000\110\000\053\000\111\000\111\000\111\000\
\082\000\082\000\007\000\007\000\007\000\084\000\084\000\085\000\
\085\000\112\000\112\000\114\000\114\000\115\000\115\000\113\000\
\113\000\116\000\116\000\117\000\117\000\000\000\000\000"

let yylen = "\002\000\
\002\000\001\000\000\000\002\000\002\000\000\000\001\000\001\000\
\003\000\005\000\005\000\003\000\004\000\001\000\006\000\004\000\
\008\000\008\000\003\000\001\000\001\000\004\000\000\000\001\000\
\001\000\001\000\001\000\003\000\004\000\001\000\002\000\004\000\
\006\000\006\000\006\000\003\000\003\000\002\000\002\000\006\000\
\001\000\003\000\002\000\001\000\002\000\002\000\002\000\004\000\
\002\000\004\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\001\000\004\000\001\000\003\000\003\000\003\000\001\000\
\003\000\003\000\001\000\003\000\003\000\001\000\003\000\003\000\
\003\000\003\000\001\000\003\000\003\000\001\000\003\000\001\000\
\003\000\001\000\003\000\001\000\003\000\001\000\003\000\001\000\
\005\000\001\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\003\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\002\000\
\001\000\002\000\002\000\001\000\001\000\001\000\001\000\003\000\
\001\000\003\000\000\000\001\000\003\000\002\000\001\000\001\000\
\000\000\003\000\004\000\005\000\000\000\001\000\002\000\000\000\
\001\000\000\000\001\000\001\000\003\000\003\000\000\000\001\000\
\003\000\003\000\003\000\003\000\005\000\003\000\001\000\000\000\
\002\000\000\000\002\000\002\000\002\000\000\000\004\000\001\000\
\003\000\001\000\002\000\001\000\003\000\005\000\003\000\003\000\
\005\000\008\000\003\000\003\000\005\000\002\000\002\000\003\000\
\002\000\002\000\003\000\004\000\007\000\001\000\005\000\004\000\
\003\000\002\000\001\000\003\000\002\000\001\000\003\000\001\000\
\003\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\002\000\004\000\000\000\001\000\000\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\002\000\005\000\004\000\006\000\005\000\002\000\005\000\
\004\000\006\000\005\000\002\000\006\000\005\000\007\000\006\000\
\001\000\004\000\004\000\000\000\003\000\002\000\004\000\003\000\
\001\000\003\000\001\000\003\000\002\000\001\000\003\000\003\000\
\001\000\003\000\003\000\001\000\004\000\005\000\005\000\004\000\
\001\000\000\000\002\000\000\000\002\000\003\000\002\000\002\000\
\001\000\003\000\002\000\005\000\003\000\001\000\003\000\000\000\
\004\000\004\000\001\000\003\000\001\000\003\000\000\000\001\000\
\002\000\001\000\003\000\001\000\004\000\003\000\004\000\004\000\
\001\000\000\000\002\000\002\000\002\000\004\000\005\000\003\000\
\001\000\001\000\001\000\000\000\002\000\000\000\002\000\005\000\
\004\000\002\000\001\000\001\000\001\000\001\000\001\000\001\000\
\004\000\002\000\001\000\002\000\001\000\001\000\003\000\002\000\
\001\000\001\000\001\000\003\000\003\000\003\000\001\000\001\000\
\003\000\002\000\003\000\003\000\001\000\002\000\004\000\002\000\
\004\000\002\000\002\000\002\000\002\000\002\000\002\000\001\000\
\001\000\003\000\003\000\003\000\001\000\003\000\003\000\001\000\
\003\000\003\000\001\000\003\000\003\000\003\000\003\000\001\000\
\003\000\003\000\001\000\003\000\001\000\003\000\001\000\003\000\
\001\000\003\000\001\000\003\000\001\000\001\000\003\000\003\000\
\003\000\003\000\000\000\002\000\002\000\001\000\002\000\000\000\
\003\000\000\000\001\000\001\000\003\000\004\000\004\000\000\000\
\003\000\000\000\002\000\001\000\003\000\002\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\233\000\209\000\211\000\215\000\
\214\000\208\000\213\000\000\000\000\000\000\000\000\000\216\000\
\217\000\212\000\210\000\042\001\000\000\000\000\041\001\043\001\
\000\000\000\000\052\001\000\000\000\000\000\000\000\000\000\000\
\000\000\051\001\000\000\014\000\000\000\000\000\000\000\142\001\
\000\000\002\000\000\000\000\000\000\000\007\000\008\000\000\000\
\000\000\000\000\000\000\143\001\000\000\000\000\020\000\021\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\205\000\194\000\000\000\000\000\000\000\
\116\000\117\000\118\000\000\000\000\000\111\000\195\000\196\000\
\197\000\198\000\005\000\000\000\200\000\000\000\000\000\000\000\
\050\001\000\000\000\000\062\001\071\001\067\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\066\001\000\000\072\001\000\000\088\001\089\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\001\000\004\000\000\000\189\000\037\001\
\000\000\000\000\000\000\024\001\000\000\207\000\199\000\006\000\
\151\000\035\001\000\000\000\000\201\000\202\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\246\000\000\000\
\000\000\058\001\000\000\000\000\000\000\000\000\060\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\009\000\112\000\000\000\000\000\
\025\000\105\000\106\000\103\000\104\000\113\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\026\000\107\000\
\000\000\027\000\000\000\000\000\000\000\030\000\000\000\058\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\090\000\102\000\000\000\000\000\000\000\
\064\001\000\000\000\000\074\001\000\000\000\000\078\001\000\000\
\080\001\082\001\083\001\084\001\087\001\085\001\086\001\000\000\
\000\000\000\000\012\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\056\001\054\001\055\001\000\000\053\001\000\000\
\000\000\188\000\000\000\000\000\000\000\252\000\011\001\000\000\
\000\000\000\000\019\000\000\000\016\000\000\000\000\000\007\001\
\008\001\000\000\000\000\000\000\003\001\038\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\238\000\
\000\000\000\000\000\000\000\000\000\000\000\000\220\000\000\000\
\000\000\000\000\225\000\000\000\000\000\000\000\000\000\000\000\
\049\001\000\000\000\000\047\000\000\000\049\000\051\000\052\000\
\053\000\056\000\054\000\055\000\057\000\000\000\045\000\046\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\234\000\115\000\114\000\025\001\000\000\235\000\000\000\
\000\000\038\000\039\000\000\000\000\000\031\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\122\001\000\000\000\000\121\001\
\073\001\068\001\069\001\000\000\000\000\063\001\070\001\013\000\
\075\001\076\001\090\001\091\001\092\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\203\000\022\001\
\045\001\191\000\000\000\119\000\193\000\000\000\000\000\000\000\
\000\000\251\000\000\000\000\000\150\000\000\000\000\000\000\000\
\000\000\015\001\000\000\000\000\010\001\000\000\000\000\000\000\
\000\000\005\001\000\000\250\000\248\000\247\000\230\000\057\001\
\022\000\000\000\000\000\000\000\240\000\245\000\237\000\000\000\
\000\000\000\000\219\000\222\000\000\000\224\000\227\000\000\000\
\010\000\011\000\000\000\000\000\000\000\146\000\000\000\000\000\
\145\000\000\000\028\000\000\000\000\000\000\000\000\000\000\000\
\037\000\036\000\000\000\137\000\000\000\000\000\000\000\091\000\
\092\000\093\000\094\000\095\000\096\000\097\000\098\000\099\000\
\100\000\101\000\061\000\062\000\063\000\060\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\139\000\000\000\
\120\001\119\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\127\000\000\000\124\000\000\000\000\000\000\000\000\000\
\000\000\013\001\000\000\000\000\000\000\000\000\047\001\000\000\
\000\000\153\000\000\000\000\000\162\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\182\000\000\000\000\000\000\000\164\000\000\000\
\021\001\000\000\000\000\015\000\000\000\000\000\001\001\027\001\
\000\000\000\000\006\001\229\000\232\000\000\000\244\000\242\000\
\239\000\221\000\226\000\000\000\000\000\000\000\142\000\141\000\
\000\000\059\000\000\000\000\000\000\000\029\000\000\000\032\000\
\148\000\147\000\000\000\000\000\000\000\000\000\000\000\000\000\
\128\000\000\000\135\000\120\000\126\000\253\000\000\000\000\000\
\144\000\000\000\000\000\000\001\161\000\159\000\000\000\000\000\
\177\000\178\000\000\000\000\000\175\000\000\000\000\000\000\000\
\000\000\174\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\156\000\163\000\155\000\149\000\000\000\
\000\000\030\001\000\000\000\000\000\000\231\000\000\000\000\000\
\000\000\041\000\000\000\089\000\000\000\000\000\134\000\130\000\
\000\000\000\000\122\000\125\000\012\001\255\000\254\000\000\000\
\185\000\171\000\179\000\000\000\176\000\000\000\167\000\172\000\
\000\000\168\000\000\000\000\000\000\000\187\000\000\000\000\000\
\000\000\000\000\124\001\125\001\000\000\020\001\017\001\018\001\
\029\001\032\001\031\001\040\000\033\000\034\000\000\000\035\000\
\043\000\017\000\018\000\131\000\000\000\048\001\180\000\000\000\
\000\000\186\000\000\000\000\000\000\000\184\000\110\000\000\000\
\000\000\042\000\132\000\173\000\169\000\000\000\166\000\183\000\
\127\001\000\000\000\000\000\000\000\000\000\000\000\000\132\001\
\000\000\000\000\000\000\000\000\129\001\000\000\181\000\170\000\
\000\000\000\000\000\000\133\001\135\001\134\001\000\000\137\001\
\000\000\139\001\000\000\141\001"

let yydgoto = "\003\000\
\040\000\041\000\042\000\043\000\014\001\178\001\139\002\060\002\
\199\000\200\000\082\001\014\002\026\002\061\002\202\000\237\001\
\102\001\077\000\203\000\027\002\028\002\029\002\160\002\162\000\
\045\000\163\000\128\000\148\000\151\000\152\000\046\000\047\000\
\048\000\205\000\063\002\064\002\026\001\183\001\145\000\129\000\
\130\000\051\001\052\001\053\001\191\001\192\001\193\001\147\002\
\132\000\054\001\049\000\050\000\223\000\188\001\022\001\041\001\
\206\000\207\000\155\002\031\002\208\000\209\000\210\000\211\000\
\212\000\213\000\214\000\215\000\216\000\217\000\218\000\219\000\
\220\000\221\000\216\002\078\000\106\002\032\002\114\002\139\000\
\185\001\089\000\183\002\217\002\227\002\079\000\135\000\051\000\
\062\000\179\001\149\000\037\001\023\001\067\002\016\001\063\000\
\107\000\108\000\109\000\110\000\111\000\112\000\113\000\114\000\
\115\000\116\000\117\000\118\000\119\000\120\000\224\000\230\002\
\237\002\231\002\232\002\248\002\250\002"

let yysindex = "\238\001\
\238\011\238\011\000\000\032\255\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\048\255\175\255\048\014\133\000\000\000\
\000\000\000\000\000\000\000\000\232\012\048\014\000\000\000\000\
\048\014\048\014\000\000\238\011\218\255\048\014\252\255\038\000\
\057\000\000\000\164\006\000\000\132\255\044\000\066\000\000\000\
\044\001\000\000\238\011\017\255\071\014\000\000\000\000\056\255\
\145\000\048\014\048\014\000\000\137\000\141\013\000\000\000\000\
\146\000\079\000\057\000\087\000\092\000\091\255\232\254\050\009\
\120\000\135\255\048\014\000\000\000\000\050\009\136\000\176\255\
\000\000\000\000\000\000\168\013\115\255\000\000\000\000\000\000\
\000\000\000\000\000\000\057\000\000\000\115\255\197\008\118\014\
\000\000\040\255\142\000\000\000\000\000\000\000\141\010\212\010\
\164\006\164\006\164\006\164\006\164\006\164\006\164\006\158\000\
\000\000\220\255\000\000\014\001\000\000\000\000\125\000\012\001\
\005\001\055\000\032\001\153\000\170\000\185\000\196\000\203\000\
\013\012\231\010\022\001\000\000\000\000\164\001\000\000\000\000\
\200\000\225\000\015\001\000\000\099\255\000\000\000\000\000\000\
\000\000\000\000\206\000\247\000\000\000\000\000\240\000\255\000\
\013\001\141\013\029\001\018\001\052\001\064\001\000\000\049\001\
\057\000\000\000\131\001\146\000\146\000\069\001\000\000\071\001\
\050\009\244\254\079\001\050\009\050\009\082\001\086\001\050\009\
\050\009\103\001\238\011\017\255\000\000\000\000\113\001\124\001\
\000\000\000\000\000\000\000\000\000\000\000\000\046\011\117\011\
\231\010\231\010\231\010\231\010\231\010\231\010\205\001\136\011\
\136\011\081\005\142\001\146\001\151\001\178\001\000\000\000\000\
\186\001\000\000\026\255\029\001\187\001\000\000\249\001\000\000\
\082\007\000\001\033\001\035\001\058\001\057\001\198\001\203\001\
\207\001\210\001\234\254\000\000\000\000\119\255\200\001\211\001\
\000\000\090\001\021\002\000\000\025\002\081\005\000\000\081\005\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\218\001\
\033\002\183\001\000\000\046\255\046\255\164\006\164\006\164\006\
\164\006\164\006\164\006\164\006\164\006\164\006\164\006\164\006\
\164\006\164\006\164\006\164\006\164\006\164\006\164\006\229\001\
\230\001\241\001\000\000\000\000\000\000\029\001\000\000\164\001\
\029\001\000\000\181\009\164\001\045\001\000\000\000\000\236\001\
\056\002\209\001\000\000\137\000\000\000\048\014\243\001\000\000\
\000\000\000\000\049\000\003\013\000\000\000\000\231\010\111\001\
\244\001\251\001\001\002\049\001\049\001\146\000\050\009\000\000\
\231\010\050\009\252\001\255\001\242\001\099\255\000\000\012\002\
\042\002\050\009\000\000\046\002\051\002\050\009\054\002\015\001\
\000\000\050\002\081\005\000\000\081\005\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\081\005\000\000\000\000\
\120\255\052\002\058\002\059\002\066\002\231\010\048\014\048\014\
\135\002\000\000\000\000\000\000\000\000\072\002\000\000\046\255\
\046\255\000\000\000\000\104\007\175\007\000\000\231\010\231\010\
\231\010\231\010\231\010\231\010\231\010\231\010\231\010\231\010\
\231\010\231\010\231\010\231\010\231\010\231\010\231\010\231\010\
\231\010\231\010\231\010\231\010\231\010\231\010\231\010\231\010\
\231\010\231\010\231\010\104\007\000\000\189\014\189\014\000\000\
\000\000\000\000\000\000\071\002\079\002\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\125\000\125\000\012\001\
\012\001\005\001\005\001\005\001\005\001\055\000\055\000\032\001\
\153\000\170\000\185\000\196\000\148\002\149\002\000\000\000\000\
\000\000\000\000\131\006\000\000\000\000\029\001\137\000\164\001\
\081\002\000\000\141\013\075\001\000\000\075\002\077\002\057\000\
\219\004\000\000\017\000\078\002\000\000\229\000\061\001\150\001\
\085\002\000\000\018\001\000\000\000\000\000\000\000\000\000\000\
\000\000\090\002\091\002\049\001\000\000\000\000\000\000\231\010\
\246\255\050\009\000\000\000\000\098\002\000\000\000\000\106\002\
\000\000\000\000\112\002\113\002\118\002\000\000\104\007\104\007\
\000\000\253\009\000\000\117\002\147\002\151\002\167\002\229\000\
\000\000\000\000\160\002\000\000\170\002\016\000\173\002\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\001\000\001\
\033\001\033\001\035\001\035\001\035\001\035\001\058\001\058\001\
\057\001\198\001\203\001\207\001\210\001\165\002\000\000\164\002\
\000\000\000\000\172\002\172\002\178\002\181\002\000\000\046\255\
\231\010\000\000\174\002\000\000\223\002\192\002\197\002\181\009\
\200\002\000\000\201\002\194\007\115\255\202\002\000\000\056\002\
\206\000\000\000\160\002\198\002\000\000\196\002\204\002\034\255\
\207\006\206\002\231\010\203\002\206\002\014\006\211\002\206\002\
\056\255\241\000\000\000\219\004\207\002\219\004\000\000\213\002\
\000\000\208\002\210\002\000\000\219\002\029\001\000\000\000\000\
\141\013\104\007\000\000\000\000\000\000\225\002\000\000\000\000\
\000\000\000\000\000\000\172\002\172\002\172\002\000\000\000\000\
\131\006\000\000\048\014\048\014\041\003\000\000\029\001\000\000\
\000\000\000\000\231\010\238\011\231\010\229\255\121\255\131\006\
\000\000\181\009\000\000\000\000\000\000\000\000\048\014\091\000\
\000\000\226\002\230\002\000\000\000\000\000\000\144\000\014\006\
\000\000\000\000\227\002\104\007\000\000\228\002\009\008\014\006\
\228\000\000\000\014\006\233\002\214\002\199\005\014\006\027\001\
\241\000\241\000\232\002\000\000\000\000\000\000\000\000\017\000\
\196\013\000\000\245\002\249\002\250\002\000\000\248\002\004\003\
\011\003\000\000\000\255\000\000\010\003\014\003\000\000\000\000\
\229\255\231\010\000\000\000\000\000\000\000\000\000\000\164\001\
\000\000\000\000\000\000\012\003\000\000\120\255\000\000\000\000\
\231\010\000\000\014\006\206\002\013\003\000\000\104\007\252\002\
\206\002\056\255\000\000\000\000\084\003\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\092\003\000\000\
\000\000\000\000\000\000\000\000\020\003\000\000\000\000\021\003\
\019\003\000\000\022\003\014\006\056\255\000\000\000\000\084\003\
\030\003\000\000\000\000\000\000\000\000\104\007\000\000\000\000\
\000\000\115\255\028\003\037\003\040\003\032\003\034\003\000\000\
\036\003\014\006\080\008\115\255\000\000\115\255\000\000\000\000\
\044\003\045\003\042\003\000\000\000\000\000\000\084\003\000\000\
\038\003\000\000\084\003\000\000"

let yyrindex = "\000\000\
\010\000\018\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\222\255\000\000\000\000\
\000\000\000\000\000\000\000\000\093\000\222\255\000\000\000\000\
\222\255\222\255\000\000\009\000\000\000\222\255\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\009\000\082\000\056\000\000\000\000\000\000\000\
\000\000\222\255\222\255\000\000\033\013\047\003\000\000\000\000\
\000\000\000\000\000\000\000\000\213\001\000\000\182\000\091\003\
\068\002\000\000\222\255\000\000\000\000\091\003\179\002\000\000\
\000\000\000\000\000\000\000\000\124\012\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\055\002\166\002\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\225\008\000\000\000\000\238\015\005\012\
\109\003\246\002\023\003\215\001\070\002\161\000\185\001\195\255\
\118\003\000\000\000\000\000\000\000\000\116\000\000\000\000\000\
\079\003\000\000\101\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\121\003\000\000\000\000\000\000\094\003\085\255\
\000\000\000\000\250\255\095\003\000\000\002\000\000\000\096\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\091\003\082\000\000\000\091\003\091\003\000\000\000\000\091\003\
\091\003\000\000\139\255\082\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\015\012\000\000\000\000\000\046\015\000\000\
\104\016\231\016\074\017\114\008\059\009\096\002\151\011\026\008\
\075\007\083\005\228\001\000\000\000\000\000\000\097\003\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\085\000\000\000\002\003\
\082\000\000\000\000\000\082\255\178\255\000\000\000\000\000\000\
\000\000\239\003\000\000\000\000\000\000\070\255\000\000\000\000\
\000\000\129\000\098\003\000\000\000\000\000\000\000\000\106\003\
\000\000\000\000\000\000\096\003\096\003\000\000\091\003\000\000\
\000\000\091\003\048\001\089\003\000\000\000\000\000\000\000\000\
\000\000\091\003\000\000\000\000\000\000\091\003\000\000\053\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\110\003\195\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\098\003\000\000\000\000\
\000\000\000\000\000\000\113\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\112\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\016\016\049\016\205\014\
\072\016\227\003\089\004\207\004\069\005\187\005\082\006\002\006\
\182\006\002\007\186\000\169\002\000\000\000\000\000\000\000\000\
\000\000\000\000\119\003\000\000\000\000\082\000\033\013\028\007\
\000\000\000\000\047\003\127\001\000\000\120\003\000\000\000\000\
\123\003\000\000\082\000\003\000\000\000\117\000\167\000\141\000\
\000\000\000\000\095\003\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\096\003\000\000\000\000\000\000\000\000\
\082\000\091\003\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\234\255\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\008\017\041\017\
\107\017\140\017\173\017\206\017\239\017\016\018\046\013\041\018\
\024\009\152\012\127\009\168\008\212\005\000\000\000\000\000\000\
\000\000\000\000\171\015\205\015\000\000\000\000\152\016\000\000\
\000\000\000\000\124\003\000\000\069\010\000\000\000\000\000\000\
\000\000\000\000\000\000\125\003\000\000\000\000\000\000\000\000\
\121\003\000\000\156\000\198\016\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\128\003\000\000\123\003\000\000\123\003\000\000\000\000\
\000\000\137\003\000\000\000\000\000\000\212\255\000\000\000\000\
\047\003\125\003\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\092\015\138\015\000\000\000\000\000\000\
\119\003\000\000\000\000\000\000\000\000\000\000\121\000\000\000\
\000\000\000\000\000\000\139\255\000\000\109\009\000\000\119\003\
\000\000\000\000\000\000\000\000\000\000\000\000\006\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\129\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\198\016\000\000\138\003\000\000\000\000\
\128\003\128\003\000\000\000\000\000\000\000\000\000\000\082\000\
\070\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\109\009\000\000\000\000\000\000\000\000\000\000\000\000\194\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\138\003\101\004\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\068\000\
\146\003\000\000\000\000\000\000\000\000\155\003\000\000\000\000\
\000\000\081\000\000\000\000\000\000\000\211\001\138\000\000\000\
\000\000\000\000\000\000\081\000\000\000\000\000\000\000\000\000\
\000\000\000\000\156\003\000\000\000\000\000\000\000\000\000\000\
\163\003\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\231\004\230\255\113\004\011\255\055\003\025\000\242\253\
\000\000\235\255\172\255\126\254\252\254\092\255\251\253\000\000\
\099\002\000\000\000\000\000\000\000\000\186\253\119\002\073\000\
\000\000\199\255\000\000\131\255\196\003\128\255\186\255\000\000\
\000\000\084\255\209\255\249\253\240\002\242\002\239\254\000\000\
\000\004\228\255\000\000\074\003\151\004\000\000\000\000\059\000\
\114\255\238\255\127\255\000\000\113\000\057\254\024\000\236\254\
\000\000\000\000\000\000\228\254\126\001\166\000\020\001\060\001\
\087\001\042\001\158\003\161\003\166\003\169\003\174\003\000\000\
\209\002\159\009\039\254\191\255\000\000\000\000\238\002\000\000\
\000\000\216\255\000\000\084\002\000\000\142\006\000\000\134\255\
\046\000\004\000\100\254\122\003\000\000\187\002\255\254\000\000\
\000\000\000\000\000\000\033\000\193\001\202\001\253\001\199\001\
\054\004\056\004\053\004\070\004\055\004\000\000\112\001\097\002\
\000\000\000\000\104\002\000\000\092\002"

let yytablesize = 4984
let yytable = "\076\000\
\138\000\083\000\201\000\015\001\034\001\173\000\024\001\054\000\
\003\000\003\000\186\001\174\000\167\000\105\000\173\001\131\000\
\125\000\003\000\154\000\180\001\031\001\084\001\038\002\202\001\
\203\001\133\000\169\001\044\001\045\001\083\001\174\001\159\002\
\073\000\091\001\123\002\061\000\065\000\009\001\071\000\133\002\
\225\000\131\001\126\000\175\000\128\002\199\002\055\000\131\002\
\055\000\228\000\135\002\056\000\140\002\056\000\142\002\136\000\
\132\001\140\001\066\000\141\001\072\000\034\001\049\001\050\001\
\176\000\083\001\105\000\083\001\200\002\016\001\058\000\126\000\
\101\001\044\000\044\000\105\000\105\000\105\000\105\000\105\000\
\105\000\105\000\044\001\059\000\040\001\158\000\068\000\044\001\
\124\002\166\000\159\002\055\000\127\000\068\000\068\000\170\000\
\056\000\068\000\068\000\055\000\044\000\053\000\068\000\048\001\
\056\000\170\002\056\001\057\001\159\000\226\000\060\001\061\001\
\042\001\175\002\227\000\044\000\178\002\134\000\032\001\057\000\
\184\002\073\000\068\000\068\000\074\000\075\000\147\000\137\000\
\035\001\234\000\235\000\236\000\237\000\238\000\239\000\055\000\
\044\001\092\001\006\000\068\000\056\000\016\001\058\000\064\001\
\063\001\016\001\085\001\106\000\172\000\015\001\219\001\044\001\
\220\001\015\001\015\001\059\000\040\001\035\002\083\001\204\000\
\083\001\221\001\157\000\060\000\170\002\060\000\195\001\165\002\
\020\001\083\001\229\001\230\001\148\002\204\001\209\002\055\000\
\055\000\046\001\180\001\213\002\056\000\056\000\085\001\078\002\
\085\001\094\001\036\002\133\001\222\001\180\001\172\001\236\001\
\239\001\044\000\161\002\134\001\223\001\223\002\162\002\044\001\
\070\002\192\002\072\002\121\000\105\000\033\001\165\000\024\001\
\060\000\003\000\196\001\046\001\023\001\074\000\075\000\240\000\
\060\000\023\001\147\000\240\002\206\001\204\000\204\000\015\002\
\105\000\105\000\105\000\105\000\105\000\105\000\105\000\105\000\
\105\000\105\000\105\000\105\000\105\000\105\000\105\000\105\000\
\105\000\105\000\095\002\044\000\064\001\205\001\064\000\169\000\
\207\001\046\001\023\001\168\001\060\000\046\001\046\001\023\001\
\213\001\228\001\039\001\181\002\216\001\016\001\093\001\117\001\
\006\000\006\000\204\000\145\001\146\001\058\000\117\001\117\001\
\065\002\006\000\024\002\085\001\204\000\085\001\147\001\148\001\
\149\001\023\001\059\000\109\002\023\001\249\002\085\001\084\000\
\044\001\249\002\204\000\204\000\060\000\060\000\204\000\242\000\
\204\000\204\000\204\000\124\000\126\000\025\002\204\000\044\001\
\204\000\055\000\044\001\117\001\211\002\015\001\056\000\206\000\
\206\000\015\001\087\002\088\002\151\002\206\000\009\001\023\001\
\049\001\086\000\023\001\015\001\015\001\015\001\009\001\126\000\
\249\000\023\001\039\001\163\002\243\000\016\001\249\000\003\000\
\026\001\023\001\023\001\204\000\023\001\023\001\172\001\023\001\
\026\001\097\002\023\001\228\002\223\001\204\000\071\001\072\001\
\073\001\074\001\075\001\076\001\036\001\164\002\187\001\253\000\
\254\000\255\000\000\001\087\000\147\000\015\001\206\000\023\001\
\105\000\105\000\062\002\122\000\044\001\044\001\190\001\233\001\
\234\001\044\001\044\001\079\002\206\000\206\000\088\000\113\002\
\206\000\024\001\206\000\206\000\206\000\055\000\024\001\123\000\
\126\001\143\000\056\000\204\000\126\002\204\000\126\001\042\002\
\140\000\033\002\150\000\204\000\153\000\130\001\204\000\023\001\
\081\002\023\001\023\001\130\001\155\000\023\001\066\002\204\000\
\204\000\023\001\204\000\156\000\166\002\113\002\060\000\223\001\
\204\000\119\002\044\001\044\001\036\001\206\000\152\002\153\002\
\192\000\192\000\206\002\246\000\247\000\248\000\059\001\034\001\
\044\001\044\001\044\001\059\001\044\001\044\001\023\001\164\000\
\044\001\023\001\030\002\073\002\103\002\028\001\024\001\023\001\
\046\001\024\001\023\001\172\001\070\000\028\001\131\001\168\000\
\034\001\044\001\204\000\003\001\131\001\033\001\181\001\172\002\
\229\000\044\001\083\001\169\002\231\000\233\000\129\002\113\001\
\113\001\015\002\006\000\058\000\069\002\113\001\004\001\006\000\
\241\000\044\001\044\001\046\001\113\001\113\001\001\000\002\000\
\059\000\046\001\046\001\046\001\005\001\062\002\024\001\062\002\
\114\001\114\001\060\000\147\000\011\001\059\001\114\001\012\001\
\013\001\172\000\006\001\027\000\172\001\114\001\114\001\140\000\
\137\002\136\002\007\001\138\002\140\000\140\000\140\000\115\002\
\158\002\113\001\015\002\172\001\017\001\172\001\010\001\251\001\
\252\001\253\001\254\001\254\001\254\001\254\001\254\001\254\001\
\254\001\254\001\254\001\254\001\254\001\254\001\254\001\254\001\
\254\001\033\002\114\001\059\001\018\001\015\001\176\002\102\002\
\019\001\177\002\025\001\035\001\068\001\070\001\114\001\115\001\
\116\001\015\002\244\000\245\000\028\001\079\001\080\001\182\002\
\249\000\250\000\027\001\029\000\011\001\251\000\252\000\012\001\
\013\001\157\002\029\001\027\000\094\001\205\002\001\001\002\001\
\033\000\030\001\034\000\126\000\011\001\117\001\118\001\012\001\
\013\001\222\000\090\000\027\000\208\002\091\000\036\001\092\000\
\073\000\039\001\011\001\119\001\120\001\012\001\013\001\125\001\
\126\001\027\000\121\001\122\001\123\001\124\001\197\001\150\000\
\030\002\093\000\175\001\066\002\094\000\176\001\185\002\186\002\
\038\001\095\000\096\000\243\000\243\000\040\001\046\001\030\002\
\192\000\192\000\071\002\043\001\172\000\176\001\172\000\090\002\
\255\001\000\002\214\002\029\000\046\001\177\001\097\000\098\000\
\099\000\147\000\047\001\100\000\101\000\055\001\242\002\102\000\
\033\000\058\001\034\000\029\000\059\001\177\001\137\001\103\000\
\046\001\187\002\188\002\204\000\204\000\224\002\007\002\008\002\
\033\000\029\000\034\000\177\001\044\000\011\001\062\001\104\000\
\012\001\013\001\001\002\002\002\027\000\065\001\033\000\187\001\
\034\000\150\001\151\001\011\001\074\000\075\000\012\001\013\001\
\066\001\044\001\027\000\046\001\152\001\153\001\046\001\158\001\
\159\001\046\001\046\001\046\001\229\002\077\001\172\000\003\002\
\004\002\005\002\006\002\086\001\228\000\228\000\229\002\087\001\
\229\002\187\001\228\000\071\002\088\001\228\000\228\000\228\000\
\228\000\228\000\228\000\044\001\228\000\228\000\228\000\228\000\
\228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
\228\000\228\000\228\000\228\000\029\000\017\002\018\002\089\001\
\115\001\154\001\155\001\156\001\157\001\115\001\090\001\095\001\
\127\001\033\000\029\000\034\000\115\001\115\001\044\001\128\001\
\254\001\044\001\129\001\228\000\044\001\044\001\044\001\033\000\
\130\001\034\000\109\001\109\001\135\001\109\001\109\001\136\001\
\138\001\228\000\228\000\109\001\139\001\228\000\142\001\228\000\
\228\000\228\000\109\001\109\001\143\001\096\001\097\001\144\001\
\088\000\115\001\088\000\165\001\166\001\088\000\088\000\088\000\
\088\000\088\000\181\001\228\000\228\000\167\001\228\000\189\001\
\182\001\184\001\199\001\098\001\099\001\210\001\100\001\200\001\
\228\000\101\001\228\000\218\000\218\000\201\001\208\001\109\001\
\228\000\218\000\228\000\209\001\218\000\218\000\218\000\218\000\
\218\000\218\000\211\001\218\000\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\218\000\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\061\001\061\001\061\001\061\001\061\001\
\061\001\061\001\061\001\061\001\061\001\061\001\061\001\061\001\
\212\001\061\001\061\001\061\001\214\001\061\001\061\001\061\001\
\061\001\215\001\218\000\061\001\217\001\218\001\225\001\226\001\
\224\001\111\001\061\001\061\001\111\001\111\001\227\001\231\001\
\218\000\218\000\111\001\019\002\218\000\232\001\218\000\218\000\
\218\000\111\001\111\001\020\002\021\002\022\002\037\002\040\002\
\041\002\068\002\078\000\078\000\078\000\074\002\078\000\078\000\
\076\002\077\002\218\000\218\000\078\000\218\000\078\000\061\001\
\082\002\078\000\078\000\078\000\078\000\078\000\078\000\218\000\
\083\002\218\000\223\000\223\000\084\002\085\002\111\001\218\000\
\223\000\218\000\086\002\223\000\223\000\223\000\223\000\223\000\
\223\000\091\002\223\000\223\000\223\000\223\000\223\000\223\000\
\223\000\223\000\223\000\223\000\223\000\223\000\223\000\223\000\
\223\000\223\000\065\001\065\001\065\001\065\001\065\001\065\001\
\065\001\065\001\065\001\065\001\065\001\065\001\065\001\092\002\
\065\001\065\001\065\001\093\002\065\001\065\001\065\001\065\001\
\116\001\223\000\065\001\094\002\223\001\116\001\096\002\099\002\
\134\001\065\001\065\001\089\002\116\001\116\001\098\002\223\000\
\223\000\100\002\104\002\223\000\101\002\223\000\223\000\223\000\
\105\002\044\001\044\001\044\001\044\001\044\001\044\001\044\001\
\044\001\044\001\107\002\108\002\110\002\111\002\116\002\121\002\
\120\002\223\000\223\000\127\002\223\000\130\002\065\001\122\002\
\134\002\116\001\141\002\143\002\144\002\145\002\223\000\146\002\
\223\000\044\001\044\001\044\001\104\001\104\001\223\000\150\002\
\223\000\154\002\168\002\167\002\180\002\189\002\171\002\173\002\
\104\001\104\001\104\001\179\002\104\001\104\001\044\001\044\001\
\044\001\193\002\104\001\044\001\044\001\194\002\196\002\044\001\
\044\001\104\001\104\001\195\002\044\001\044\001\044\001\044\001\
\197\002\044\001\044\001\044\001\044\001\044\001\044\001\198\002\
\202\002\107\001\107\001\107\001\203\002\107\001\107\001\207\002\
\210\002\212\002\215\002\107\001\218\002\219\002\221\002\220\002\
\233\002\222\002\107\001\107\001\044\001\044\001\104\001\044\001\
\226\002\234\002\236\002\044\001\044\001\235\002\238\002\239\002\
\245\002\246\002\251\002\002\001\247\002\006\000\044\001\044\001\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\107\001\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\190\000\099\001\099\001\099\001\099\001\099\001\
\099\001\236\000\014\001\004\001\241\000\118\001\023\000\099\001\
\099\001\099\001\034\001\099\001\099\001\158\000\158\000\158\000\
\024\000\099\001\158\000\158\000\006\000\136\000\158\000\158\000\
\099\001\099\001\138\000\158\000\158\000\123\000\158\000\158\000\
\158\000\154\000\121\000\160\000\158\000\123\001\143\000\157\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\019\001\138\000\128\001\158\000\
\158\000\158\000\158\000\158\000\158\000\099\001\158\000\138\000\
\138\001\158\000\158\000\158\000\158\000\158\000\158\000\140\001\
\052\000\008\001\039\002\198\001\158\000\158\000\152\000\152\000\
\152\000\152\000\152\000\152\000\152\000\152\000\152\000\152\000\
\152\000\152\000\152\000\152\000\152\000\201\002\152\000\152\000\
\152\000\152\000\152\000\152\000\152\000\152\000\152\000\152\000\
\152\000\152\000\152\000\152\000\152\000\152\000\152\000\152\000\
\170\001\100\001\100\001\100\001\100\001\100\001\100\001\204\002\
\118\002\117\002\080\002\021\001\009\002\100\001\100\001\100\001\
\010\002\100\001\100\001\152\000\152\000\152\000\011\002\100\001\
\152\000\152\000\012\002\225\002\152\000\152\000\100\001\100\001\
\013\002\152\000\152\000\156\002\152\000\152\000\152\000\149\002\
\160\001\162\001\152\000\161\001\075\002\164\001\152\000\152\000\
\152\000\152\000\152\000\152\000\152\000\152\000\152\000\152\000\
\152\000\152\000\190\002\163\001\243\002\152\000\152\000\152\000\
\152\000\152\000\152\000\100\001\152\000\244\002\252\002\000\000\
\152\000\152\000\152\000\152\000\152\000\000\000\000\000\000\000\
\000\000\000\000\152\000\152\000\165\000\165\000\165\000\165\000\
\165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
\165\000\165\000\165\000\000\000\165\000\165\000\165\000\165\000\
\165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
\165\000\165\000\165\000\165\000\165\000\165\000\000\000\101\001\
\101\001\101\001\101\001\101\001\101\001\000\000\000\000\000\000\
\000\000\000\000\000\000\101\001\101\001\101\001\000\000\101\001\
\101\001\165\000\165\000\165\000\000\000\101\001\165\000\165\000\
\000\000\000\000\165\000\165\000\101\001\101\001\000\000\165\000\
\165\000\000\000\165\000\165\000\165\000\000\000\000\000\000\000\
\165\000\000\000\000\000\000\000\165\000\165\000\165\000\165\000\
\165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
\000\000\000\000\000\000\165\000\165\000\165\000\165\000\165\000\
\165\000\101\001\165\000\000\000\000\000\000\000\165\000\165\000\
\165\000\165\000\165\000\000\000\000\000\000\000\000\000\000\000\
\165\000\165\000\043\002\044\002\178\000\179\000\180\000\181\000\
\005\000\073\000\182\000\006\000\007\000\008\000\009\000\010\000\
\011\000\000\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\067\000\022\000\023\000\024\000\025\000\
\026\000\027\000\183\000\184\000\000\000\102\001\102\001\102\001\
\102\001\102\001\102\001\000\000\000\000\000\000\000\000\000\000\
\000\000\102\001\102\001\102\001\000\000\102\001\102\001\185\000\
\186\000\187\000\000\000\102\001\188\000\189\000\000\000\000\000\
\190\000\191\000\102\001\102\001\000\000\192\000\193\000\000\000\
\194\000\000\000\137\000\000\000\000\000\000\000\045\002\000\000\
\000\000\000\000\046\002\047\002\048\002\049\002\050\002\051\002\
\052\002\053\002\054\002\055\002\056\002\057\002\000\000\000\000\
\000\000\029\000\030\000\058\002\032\000\074\000\075\000\102\001\
\195\000\000\000\000\000\000\000\196\000\197\000\033\000\059\002\
\034\000\000\000\000\000\000\000\000\000\000\000\039\000\198\000\
\081\001\177\000\178\000\179\000\180\000\181\000\005\000\073\000\
\182\000\006\000\007\000\008\000\009\000\010\000\011\000\000\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\067\000\022\000\023\000\024\000\025\000\026\000\027\000\
\183\000\184\000\000\000\103\001\103\001\103\001\103\001\103\001\
\103\001\000\000\000\000\000\000\000\000\000\000\000\000\103\001\
\103\001\103\001\000\000\103\001\103\001\185\000\186\000\187\000\
\000\000\103\001\188\000\189\000\000\000\000\000\190\000\191\000\
\103\001\103\001\086\000\192\000\193\000\000\000\194\000\086\000\
\137\000\086\000\000\000\069\000\086\000\086\000\086\000\086\000\
\086\000\086\000\000\000\080\000\000\000\000\000\081\000\082\000\
\000\000\000\000\000\000\085\000\000\000\000\000\000\000\029\000\
\030\000\000\000\032\000\074\000\075\000\103\001\195\000\000\000\
\000\000\000\000\196\000\197\000\033\000\000\000\034\000\141\000\
\142\000\000\000\000\000\000\000\039\000\198\000\235\001\177\000\
\178\000\179\000\180\000\181\000\005\000\073\000\182\000\006\000\
\007\000\008\000\009\000\010\000\011\000\000\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\067\000\
\022\000\023\000\024\000\025\000\026\000\027\000\183\000\184\000\
\000\000\105\001\105\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\105\001\105\001\105\001\
\000\000\105\001\105\001\185\000\186\000\187\000\000\000\105\001\
\188\000\189\000\000\000\000\000\190\000\191\000\105\001\105\001\
\000\000\192\000\193\000\000\000\194\000\043\002\132\002\178\000\
\179\000\180\000\181\000\087\000\073\000\182\000\000\000\000\000\
\087\000\000\000\087\000\000\000\000\000\087\000\087\000\087\000\
\087\000\087\000\087\000\000\000\000\000\029\000\030\000\000\000\
\032\000\074\000\075\000\105\001\195\000\183\000\184\000\000\000\
\196\000\197\000\033\000\000\000\034\000\000\000\000\000\000\000\
\000\000\000\000\039\000\198\000\108\001\108\001\108\001\000\000\
\108\001\108\001\185\000\186\000\187\000\000\000\108\001\188\000\
\189\000\000\000\000\000\190\000\191\000\108\001\108\001\000\000\
\192\000\193\000\000\000\194\000\000\000\137\000\000\000\000\000\
\000\000\045\002\000\000\000\000\000\000\046\002\047\002\048\002\
\049\002\050\002\051\002\052\002\053\002\054\002\055\002\056\002\
\057\002\000\000\000\000\000\000\000\000\000\000\058\002\000\000\
\074\000\075\000\108\001\195\000\000\000\000\000\000\000\196\000\
\197\000\000\000\059\002\000\000\000\000\000\000\000\000\000\000\
\106\001\106\001\198\000\023\002\178\000\179\000\180\000\181\000\
\056\000\073\000\182\000\000\000\106\001\106\001\106\001\000\000\
\106\001\106\001\000\000\000\000\000\000\000\000\106\001\000\000\
\000\000\000\000\000\000\000\000\000\000\106\001\106\001\000\000\
\000\000\000\000\183\000\184\000\090\000\000\000\000\000\091\000\
\000\000\092\000\073\000\000\000\000\000\000\000\000\000\000\000\
\024\002\000\000\000\000\000\000\000\000\000\000\000\000\185\000\
\186\000\187\000\000\000\093\000\188\000\189\000\094\000\000\000\
\190\000\191\000\106\001\095\000\096\000\192\000\193\000\000\000\
\194\000\000\000\171\001\025\002\000\000\000\000\235\001\177\000\
\178\000\179\000\180\000\181\000\000\000\073\000\182\000\000\000\
\097\000\098\000\099\000\000\000\000\000\100\000\101\000\000\000\
\000\000\102\000\000\000\000\000\000\000\074\000\075\000\000\000\
\195\000\103\000\000\000\000\000\196\000\197\000\183\000\184\000\
\000\000\110\001\110\001\000\000\110\001\110\001\000\000\198\000\
\060\000\104\000\110\001\000\000\000\000\000\000\000\000\000\000\
\000\000\110\001\110\001\185\000\186\000\187\000\074\000\075\000\
\188\000\189\000\000\000\000\000\190\000\191\000\000\000\000\000\
\000\000\192\000\193\000\000\000\194\000\000\000\000\000\000\000\
\000\000\000\000\125\002\044\001\044\001\044\001\044\001\044\001\
\044\001\000\000\044\001\044\001\000\000\000\000\110\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\074\000\075\000\000\000\195\000\000\000\000\000\000\000\
\196\000\197\000\000\000\044\001\044\001\112\001\000\000\000\000\
\112\001\112\001\000\000\198\000\000\000\000\000\112\001\000\000\
\000\000\000\000\000\000\000\000\000\000\112\001\112\001\000\000\
\044\001\044\001\044\001\000\000\000\000\044\001\044\001\000\000\
\000\000\044\001\044\001\000\000\000\000\000\000\044\001\044\001\
\000\000\044\001\000\000\000\000\000\000\044\001\000\000\235\001\
\177\000\178\000\179\000\180\000\181\000\000\000\073\000\182\000\
\000\000\000\000\112\001\103\001\104\001\105\001\106\001\107\001\
\108\001\109\001\110\001\111\001\112\001\113\001\044\001\044\001\
\000\000\044\001\000\000\000\000\000\000\044\001\044\001\183\000\
\184\000\084\000\084\000\000\000\000\000\000\000\000\000\084\000\
\044\001\084\000\000\000\000\000\084\000\084\000\084\000\084\000\
\084\000\084\000\000\000\000\000\185\000\186\000\187\000\000\000\
\000\000\188\000\189\000\000\000\000\000\190\000\191\000\000\000\
\000\000\000\000\192\000\193\000\000\000\194\000\238\001\177\000\
\178\000\179\000\180\000\181\000\000\000\073\000\182\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\112\002\177\000\178\000\179\000\180\000\181\000\000\000\
\073\000\182\000\074\000\075\000\000\000\195\000\183\000\184\000\
\000\000\196\000\197\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\198\000\000\000\000\000\000\000\
\000\000\183\000\184\000\185\000\186\000\187\000\000\000\000\000\
\188\000\189\000\000\000\000\000\190\000\191\000\000\000\000\000\
\000\000\192\000\193\000\000\000\194\000\000\000\185\000\186\000\
\187\000\000\000\000\000\188\000\189\000\000\000\000\000\190\000\
\191\000\000\000\000\000\000\000\192\000\193\000\000\000\194\000\
\174\002\177\000\178\000\179\000\180\000\181\000\000\000\073\000\
\182\000\074\000\075\000\000\000\195\000\000\000\000\000\000\000\
\196\000\197\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\198\000\074\000\075\000\000\000\195\000\
\183\000\184\000\000\000\196\000\197\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\198\000\000\000\
\000\000\000\000\000\000\000\000\000\000\185\000\186\000\187\000\
\000\000\000\000\188\000\189\000\000\000\000\000\190\000\191\000\
\000\000\000\000\000\000\192\000\193\000\000\000\194\000\241\002\
\177\000\178\000\179\000\180\000\181\000\082\000\073\000\182\000\
\082\000\082\000\000\000\000\000\000\000\000\000\082\000\000\000\
\082\000\000\000\000\000\082\000\082\000\082\000\082\000\082\000\
\082\000\000\000\000\000\074\000\075\000\000\000\195\000\183\000\
\184\000\000\000\196\000\197\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\198\000\000\000\000\000\
\000\000\000\000\000\000\000\000\185\000\186\000\187\000\000\000\
\000\000\188\000\189\000\000\000\000\000\190\000\191\000\000\000\
\000\000\000\000\192\000\193\000\000\000\194\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\070\000\070\000\070\000\070\000\070\000\070\000\000\000\000\000\
\000\000\000\000\000\000\000\000\070\000\070\000\070\000\000\000\
\070\000\070\000\074\000\075\000\000\000\195\000\070\000\000\000\
\070\000\196\000\197\000\070\000\070\000\070\000\070\000\070\000\
\070\000\000\000\000\000\000\000\198\000\177\000\178\000\179\000\
\180\000\181\000\005\000\073\000\182\000\006\000\007\000\008\000\
\009\000\010\000\011\000\000\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\067\000\022\000\023\000\
\024\000\025\000\026\000\027\000\183\000\184\000\085\000\085\000\
\000\000\000\000\000\000\000\000\085\000\000\000\085\000\000\000\
\000\000\085\000\085\000\085\000\085\000\085\000\085\000\000\000\
\000\000\185\000\186\000\187\000\000\000\000\000\188\000\189\000\
\000\000\000\000\190\000\191\000\000\000\000\000\000\000\192\000\
\193\000\000\000\194\000\000\000\000\000\000\000\000\000\077\001\
\077\001\077\001\077\001\077\001\077\001\077\001\077\001\077\001\
\077\001\077\001\000\000\077\001\077\001\077\001\000\000\077\001\
\077\001\077\001\077\001\029\000\030\000\077\001\032\000\074\000\
\075\000\000\000\195\000\000\000\077\001\077\001\196\000\197\000\
\033\000\160\000\034\000\000\000\000\000\000\000\000\000\005\000\
\039\000\198\000\006\000\007\000\008\000\009\000\010\000\011\000\
\000\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\067\000\022\000\023\000\024\000\025\000\026\000\
\027\000\077\001\079\000\079\000\079\000\000\000\079\000\079\000\
\000\000\000\000\000\000\000\000\079\000\000\000\079\000\000\000\
\000\000\079\000\079\000\079\000\079\000\079\000\079\000\000\000\
\000\000\075\000\075\000\000\000\000\000\133\000\133\000\133\000\
\133\000\133\000\000\000\133\000\133\000\075\000\075\000\075\000\
\000\000\075\000\075\000\000\000\000\000\161\000\000\000\075\000\
\000\000\075\000\000\000\000\000\075\000\075\000\075\000\075\000\
\075\000\075\000\000\000\000\000\133\000\133\000\133\000\000\000\
\029\000\030\000\000\000\032\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\033\000\000\000\034\000\
\000\000\133\000\133\000\133\000\000\000\039\000\133\000\133\000\
\000\000\000\000\133\000\133\000\000\000\000\000\000\000\133\000\
\133\000\000\000\133\000\000\000\133\000\177\000\178\000\179\000\
\180\000\181\000\083\000\073\000\182\000\083\000\083\000\000\000\
\000\000\000\000\000\000\083\000\000\000\083\000\000\000\000\000\
\083\000\083\000\083\000\083\000\083\000\083\000\000\000\133\000\
\133\000\000\000\133\000\000\000\183\000\184\000\133\000\133\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\133\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\185\000\186\000\187\000\000\000\000\000\188\000\189\000\
\000\000\000\000\190\000\191\000\000\000\000\000\000\000\192\000\
\193\000\000\000\194\000\000\000\171\001\177\000\178\000\179\000\
\180\000\181\000\000\000\073\000\182\000\240\001\241\001\242\001\
\243\001\244\001\245\001\246\001\247\001\248\001\249\001\250\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\074\000\
\075\000\000\000\195\000\000\000\183\000\184\000\196\000\197\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\198\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\185\000\186\000\187\000\000\000\000\000\188\000\189\000\
\000\000\000\000\190\000\191\000\000\000\000\000\000\000\192\000\
\193\000\000\000\194\000\000\000\089\002\129\000\129\000\129\000\
\129\000\129\000\000\000\129\000\129\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\074\000\
\075\000\000\000\195\000\000\000\129\000\129\000\196\000\197\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\198\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\129\000\129\000\129\000\000\000\000\000\129\000\129\000\
\000\000\000\000\129\000\129\000\000\000\000\000\000\000\129\000\
\129\000\000\000\129\000\000\000\129\000\177\000\178\000\179\000\
\180\000\181\000\000\000\073\000\182\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\129\000\
\129\000\000\000\129\000\000\000\183\000\184\000\129\000\129\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\129\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\185\000\186\000\187\000\000\000\000\000\188\000\189\000\
\000\000\000\000\190\000\191\000\000\000\000\000\000\000\192\000\
\193\000\000\000\230\000\000\000\177\000\178\000\179\000\180\000\
\181\000\000\000\073\000\182\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\177\000\
\178\000\179\000\180\000\181\000\000\000\073\000\182\000\074\000\
\075\000\000\000\195\000\183\000\184\000\000\000\196\000\197\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\198\000\000\000\000\000\000\000\000\000\183\000\184\000\
\185\000\186\000\187\000\000\000\000\000\188\000\189\000\000\000\
\000\000\190\000\191\000\000\000\000\000\000\000\192\000\193\000\
\000\000\232\000\000\000\185\000\186\000\187\000\000\000\000\000\
\188\000\189\000\000\000\000\000\190\000\191\000\000\000\000\000\
\000\000\192\000\193\000\000\000\194\000\000\000\177\000\178\000\
\179\000\180\000\181\000\000\000\073\000\182\000\074\000\075\000\
\000\000\195\000\000\000\000\000\000\000\196\000\197\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\198\000\074\000\075\000\000\000\195\000\183\000\184\000\000\000\
\196\000\197\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\198\000\000\000\000\000\000\000\000\000\
\000\000\000\000\185\000\186\000\187\000\000\000\000\000\188\000\
\189\000\000\000\000\000\190\000\191\000\000\000\000\000\000\000\
\192\000\193\000\000\000\067\001\000\000\177\000\178\000\179\000\
\180\000\181\000\000\000\073\000\182\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\177\000\178\000\179\000\180\000\181\000\000\000\073\000\182\000\
\074\000\075\000\000\000\195\000\183\000\184\000\000\000\196\000\
\197\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\198\000\000\000\000\000\000\000\000\000\183\000\
\184\000\185\000\186\000\187\000\000\000\000\000\188\000\189\000\
\000\000\000\000\190\000\191\000\000\000\000\000\000\000\192\000\
\193\000\000\000\069\001\000\000\185\000\186\000\187\000\000\000\
\000\000\188\000\189\000\000\000\000\000\190\000\191\000\000\000\
\000\000\000\000\192\000\193\000\000\000\078\001\000\000\000\000\
\000\000\000\000\080\000\080\000\000\000\080\000\080\000\074\000\
\075\000\000\000\195\000\080\000\000\000\080\000\196\000\197\000\
\080\000\080\000\080\000\080\000\080\000\080\000\000\000\000\000\
\000\000\198\000\074\000\075\000\000\000\195\000\004\000\000\000\
\000\000\196\000\197\000\005\000\000\000\000\000\006\000\007\000\
\008\000\009\000\010\000\011\000\198\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\026\000\027\000\004\000\000\000\000\000\
\000\000\000\000\005\000\000\000\000\000\006\000\007\000\008\000\
\009\000\010\000\011\000\000\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\026\000\027\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\096\001\096\001\096\001\096\001\096\001\
\096\001\028\000\000\000\000\000\000\000\000\000\000\000\096\001\
\096\001\096\001\000\000\096\001\096\001\096\001\096\001\000\000\
\000\000\096\001\000\000\000\000\029\000\030\000\031\000\032\000\
\096\001\096\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\033\000\000\000\034\000\035\000\036\000\000\000\037\000\
\038\000\039\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\029\000\030\000\031\000\032\000\000\000\
\000\000\000\000\000\000\000\000\000\000\096\001\000\000\000\000\
\033\000\000\000\034\000\035\000\036\000\000\000\037\000\038\000\
\039\000\109\000\000\000\000\000\109\000\109\000\109\000\109\000\
\109\000\109\000\000\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\000\000\000\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\000\000\109\000\109\000\
\109\000\000\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\081\000\081\000\000\000\081\000\081\000\
\000\000\000\000\109\000\109\000\081\000\109\000\081\000\000\000\
\000\000\081\000\081\000\081\000\081\000\081\000\081\000\109\000\
\000\000\109\000\000\000\000\000\109\000\005\000\073\000\109\000\
\006\000\007\000\008\000\009\000\010\000\011\000\000\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\067\000\022\000\023\000\024\000\025\000\026\000\027\000\000\000\
\005\000\000\000\000\000\006\000\007\000\008\000\009\000\010\000\
\011\000\000\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\067\000\022\000\023\000\024\000\025\000\
\026\000\027\000\000\000\000\000\000\000\000\000\001\001\000\000\
\000\000\001\001\001\001\001\001\001\001\001\001\001\001\000\000\
\001\001\001\001\001\001\001\001\001\001\001\001\001\001\001\001\
\001\001\001\001\001\001\001\001\001\001\001\001\001\001\001\001\
\000\000\000\000\000\000\000\000\000\000\000\000\029\000\030\000\
\146\000\032\000\074\000\075\000\000\000\000\000\000\000\000\000\
\194\001\000\000\000\000\033\000\000\000\034\000\000\000\000\000\
\000\000\000\000\000\000\039\000\076\000\076\000\000\000\000\000\
\000\000\029\000\030\000\000\000\032\000\001\001\001\001\000\000\
\076\000\076\000\076\000\000\000\076\000\076\000\033\000\000\000\
\034\000\000\000\076\000\000\000\076\000\000\000\039\000\076\000\
\076\000\076\000\076\000\076\000\076\000\000\000\000\000\001\001\
\001\001\000\000\001\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\001\001\000\000\001\001\000\000\
\000\000\000\000\005\000\000\000\001\001\006\000\007\000\008\000\
\009\000\010\000\011\000\000\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\067\000\022\000\023\000\
\024\000\025\000\026\000\027\000\000\000\005\000\000\000\000\000\
\006\000\007\000\008\000\009\000\010\000\011\000\000\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\067\000\022\000\023\000\024\000\025\000\026\000\027\000\000\000\
\000\000\005\000\000\000\000\000\006\000\007\000\008\000\009\000\
\010\000\011\000\146\000\012\000\013\000\014\000\015\000\016\000\
\017\000\018\000\019\000\020\000\067\000\022\000\023\000\024\000\
\025\000\026\000\027\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\029\000\030\000\000\000\032\000\171\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\033\000\000\000\034\000\000\000\000\000\000\000\000\000\000\000\
\039\000\000\000\000\000\000\000\000\000\000\000\029\000\030\000\
\000\000\032\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\191\002\000\000\033\000\000\000\034\000\000\000\000\000\
\000\000\000\000\000\000\039\000\000\000\000\000\000\000\000\000\
\000\000\000\000\029\000\030\000\000\000\032\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\033\000\
\000\000\034\000\000\000\000\000\000\000\005\000\000\000\039\000\
\006\000\007\000\008\000\009\000\010\000\011\000\000\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\067\000\022\000\023\000\024\000\025\000\026\000\027\000\006\000\
\007\000\008\000\009\000\010\000\011\000\000\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\067\000\
\022\000\023\000\024\000\025\000\026\000\027\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\222\000\090\000\000\000\
\000\000\091\000\000\000\092\000\073\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\093\000\029\000\030\000\
\094\000\032\000\000\000\000\000\000\000\095\000\096\000\000\000\
\000\000\000\000\000\000\033\000\000\000\034\000\000\000\000\000\
\000\000\000\000\000\000\039\000\000\000\029\000\030\000\000\000\
\032\000\000\000\097\000\098\000\099\000\000\000\000\000\100\000\
\101\000\000\000\033\000\102\000\034\000\000\000\000\000\000\000\
\000\000\000\000\039\000\103\000\016\002\090\000\000\000\000\000\
\091\000\000\000\092\000\073\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\104\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\093\000\000\000\000\000\094\000\
\074\000\075\000\000\000\000\000\095\000\096\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\097\000\098\000\099\000\000\000\000\000\100\000\101\000\
\000\000\000\000\102\000\097\001\097\001\097\001\097\001\097\001\
\097\001\000\000\103\000\000\000\000\000\000\000\000\000\097\001\
\097\001\097\001\000\000\097\001\097\001\097\001\097\001\000\000\
\000\000\097\001\104\000\000\000\000\000\000\000\000\000\000\000\
\097\001\097\001\000\000\000\000\000\000\000\000\000\000\074\000\
\075\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\000\000\108\000\108\000\108\000\097\001\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\000\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\044\000\
\044\000\044\000\044\000\044\000\044\000\044\000\044\000\044\000\
\044\000\044\000\000\000\000\000\044\000\044\000\044\000\044\000\
\044\000\044\000\044\000\044\000\044\000\044\000\044\000\000\000\
\044\000\044\000\044\000\000\000\044\000\044\000\044\000\044\000\
\108\000\000\000\044\000\000\000\044\000\000\000\000\000\044\000\
\044\000\044\000\044\000\044\000\044\000\048\000\048\000\048\000\
\048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
\000\000\000\000\048\000\048\000\048\000\048\000\048\000\048\000\
\048\000\048\000\048\000\048\000\048\000\000\000\048\000\048\000\
\048\000\000\000\048\000\048\000\048\000\048\000\044\000\000\000\
\048\000\000\000\048\000\000\000\000\000\048\000\048\000\048\000\
\048\000\048\000\048\000\050\000\050\000\050\000\050\000\050\000\
\050\000\050\000\050\000\050\000\050\000\050\000\000\000\000\000\
\050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
\050\000\050\000\050\000\000\000\050\000\050\000\050\000\000\000\
\050\000\050\000\050\000\050\000\048\000\000\000\050\000\000\000\
\050\000\000\000\000\000\050\000\050\000\050\000\050\000\050\000\
\050\000\079\001\079\001\079\001\079\001\079\001\079\001\079\001\
\079\001\079\001\079\001\079\001\000\000\079\001\079\001\079\001\
\000\000\079\001\079\001\079\001\079\001\000\000\000\000\079\001\
\000\000\000\000\000\000\000\000\000\000\000\000\079\001\079\001\
\000\000\000\000\050\000\081\001\081\001\081\001\081\001\081\001\
\081\001\081\001\081\001\081\001\081\001\081\001\000\000\081\001\
\081\001\081\001\000\000\081\001\081\001\081\001\081\001\000\000\
\000\000\081\001\000\000\000\000\000\000\000\000\000\000\000\000\
\081\001\081\001\000\000\079\001\093\001\093\001\093\001\093\001\
\093\001\093\001\093\001\093\001\000\000\000\000\000\000\000\000\
\093\001\093\001\093\001\000\000\093\001\093\001\093\001\093\001\
\000\000\000\000\093\001\000\000\000\000\000\000\000\000\000\000\
\000\000\093\001\093\001\000\000\000\000\081\001\094\001\094\001\
\094\001\094\001\094\001\094\001\094\001\094\001\000\000\000\000\
\000\000\000\000\094\001\094\001\094\001\000\000\094\001\094\001\
\094\001\094\001\000\000\000\000\094\001\000\000\000\000\000\000\
\000\000\000\000\000\000\094\001\094\001\000\000\093\001\095\001\
\095\001\095\001\095\001\095\001\095\001\095\001\095\001\000\000\
\000\000\000\000\000\000\095\001\095\001\095\001\000\000\095\001\
\095\001\095\001\095\001\000\000\000\000\095\001\098\001\098\001\
\098\001\098\001\098\001\098\001\095\001\095\001\000\000\000\000\
\094\001\000\000\098\001\098\001\098\001\000\000\098\001\098\001\
\098\001\098\001\000\000\000\000\098\001\000\000\000\000\000\000\
\000\000\000\000\000\000\098\001\098\001\000\000\060\000\060\000\
\060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
\060\000\095\001\060\000\060\000\060\000\000\000\060\000\060\000\
\060\000\060\000\000\000\000\000\060\000\000\000\060\000\000\000\
\000\000\060\000\060\000\060\000\060\000\060\000\060\000\000\000\
\098\001\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\000\000\025\000\025\000\025\000\000\000\025\000\025\000\
\025\000\025\000\025\000\025\000\000\000\025\000\025\000\000\000\
\025\000\000\000\020\000\000\000\025\000\000\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\000\000\
\025\000\025\000\025\000\000\000\025\000\025\000\025\000\025\000\
\025\000\025\000\000\000\025\000\000\000\000\000\025\000\000\000\
\000\000\025\000\025\000\000\000\025\000\064\000\064\000\064\000\
\064\000\064\000\064\000\064\000\064\000\000\000\000\000\000\000\
\000\000\064\000\064\000\064\000\000\000\064\000\064\000\064\000\
\064\000\000\000\000\000\064\000\000\000\064\000\000\000\000\000\
\064\000\064\000\064\000\064\000\064\000\064\000\065\000\065\000\
\065\000\065\000\065\000\065\000\065\000\065\000\000\000\000\000\
\000\000\000\000\065\000\065\000\065\000\000\000\065\000\065\000\
\065\000\065\000\000\000\000\000\065\000\000\000\065\000\000\000\
\000\000\065\000\065\000\065\000\065\000\065\000\065\000\066\000\
\066\000\066\000\066\000\066\000\066\000\066\000\066\000\000\000\
\000\000\000\000\000\000\066\000\066\000\066\000\000\000\066\000\
\066\000\066\000\066\000\000\000\000\000\066\000\000\000\066\000\
\000\000\000\000\066\000\066\000\066\000\066\000\066\000\066\000\
\067\000\067\000\067\000\067\000\067\000\067\000\000\000\000\000\
\000\000\000\000\000\000\000\000\067\000\067\000\067\000\000\000\
\067\000\067\000\067\000\067\000\000\000\000\000\067\000\000\000\
\067\000\000\000\000\000\067\000\067\000\067\000\067\000\067\000\
\067\000\068\000\068\000\068\000\068\000\068\000\068\000\000\000\
\000\000\000\000\000\000\000\000\000\000\068\000\068\000\068\000\
\000\000\068\000\068\000\068\000\068\000\000\000\000\000\068\000\
\000\000\068\000\000\000\000\000\068\000\068\000\068\000\068\000\
\068\000\068\000\069\000\069\000\069\000\069\000\069\000\069\000\
\000\000\000\000\000\000\000\000\000\000\000\000\069\000\069\000\
\069\000\000\000\069\000\069\000\069\000\069\000\000\000\000\000\
\069\000\000\000\069\000\000\000\000\000\069\000\069\000\069\000\
\069\000\069\000\069\000\071\000\071\000\071\000\071\000\071\000\
\071\000\000\000\000\000\000\000\000\000\000\000\000\000\071\000\
\071\000\071\000\000\000\071\000\071\000\000\000\000\000\000\000\
\000\000\071\000\000\000\071\000\000\000\000\000\071\000\071\000\
\071\000\071\000\071\000\071\000\072\000\072\000\072\000\072\000\
\072\000\072\000\000\000\000\000\000\000\000\000\000\000\000\000\
\072\000\072\000\072\000\000\000\072\000\072\000\000\000\000\000\
\000\000\000\000\072\000\000\000\072\000\000\000\000\000\072\000\
\072\000\072\000\072\000\072\000\072\000\073\000\073\000\073\000\
\073\000\073\000\073\000\000\000\000\000\000\000\000\000\000\000\
\000\000\073\000\073\000\073\000\000\000\073\000\073\000\000\000\
\000\000\000\000\000\000\073\000\000\000\073\000\000\000\000\000\
\073\000\073\000\073\000\073\000\073\000\073\000\074\000\074\000\
\074\000\074\000\074\000\074\000\000\000\000\000\000\000\000\000\
\000\000\000\000\074\000\074\000\074\000\000\000\074\000\074\000\
\000\000\000\000\000\000\000\000\074\000\000\000\074\000\077\000\
\077\000\074\000\074\000\074\000\074\000\074\000\074\000\000\000\
\000\000\000\000\000\000\077\000\077\000\077\000\000\000\077\000\
\077\000\000\000\000\000\000\000\000\000\077\000\000\000\077\000\
\000\000\000\000\077\000\077\000\077\000\077\000\077\000\077\000"

let yycheck = "\021\000\
\048\000\028\000\087\000\126\000\147\000\076\000\136\000\004\000\
\000\000\000\000\028\001\077\000\070\000\035\000\019\001\044\000\
\043\000\000\000\059\000\021\001\146\000\194\000\179\001\044\001\
\045\001\044\000\016\001\156\000\157\000\194\000\020\001\102\002\
\007\001\008\001\001\001\012\000\013\000\122\000\015\000\054\002\
\001\001\064\001\055\001\084\000\050\002\046\001\001\001\053\002\
\001\001\090\000\056\002\006\001\060\002\006\001\062\002\000\001\
\079\001\230\000\013\000\232\000\015\000\204\000\075\001\076\001\
\086\000\230\000\088\000\232\000\069\001\000\001\095\001\055\001\
\073\001\001\000\002\000\097\000\098\000\099\000\100\000\101\000\
\102\000\103\000\001\001\108\001\000\001\062\000\014\000\006\001\
\055\001\066\000\161\002\001\001\076\001\021\000\022\000\072\000\
\006\001\025\000\026\000\001\001\028\000\070\001\030\000\161\000\
\006\001\120\002\164\000\165\000\063\000\070\001\168\000\169\000\
\153\000\128\002\075\001\043\000\131\002\045\000\147\000\072\001\
\135\002\007\001\050\000\051\000\099\001\100\001\054\000\072\001\
\147\000\097\000\098\000\099\000\100\000\101\000\102\000\001\001\
\055\001\203\000\000\001\067\000\006\001\072\001\095\001\172\000\
\171\000\076\001\194\000\035\000\076\000\016\001\067\001\070\001\
\069\001\020\001\021\001\108\001\072\001\175\001\067\001\087\000\
\069\001\078\001\072\001\118\001\179\002\118\001\036\001\111\002\
\070\001\078\001\087\001\088\001\073\002\046\001\180\002\001\001\
\001\001\000\001\180\001\185\002\006\001\006\001\230\000\204\001\
\232\000\204\000\176\001\069\001\069\001\191\001\019\001\100\001\
\101\001\121\000\074\001\077\001\077\001\212\002\078\001\118\001\
\190\001\145\002\192\001\072\001\226\000\147\000\072\001\081\001\
\118\001\071\001\039\001\034\001\001\001\099\001\100\001\103\000\
\118\001\006\001\146\000\234\002\049\001\000\001\001\001\132\001\
\246\000\247\000\248\000\249\000\250\000\251\000\252\000\253\000\
\254\000\255\000\000\001\001\001\002\001\003\001\004\001\005\001\
\006\001\007\001\232\001\171\000\017\001\047\001\072\001\072\001\
\050\001\072\001\001\001\014\001\118\001\076\001\077\001\006\001\
\058\001\086\001\000\001\134\002\062\001\000\001\204\000\069\001\
\000\001\000\001\194\000\244\000\245\000\095\001\076\001\077\001\
\000\001\000\001\046\001\067\001\055\001\069\001\246\000\247\000\
\248\000\070\001\108\001\032\002\073\001\247\002\078\001\070\001\
\055\001\251\002\069\001\070\001\118\001\118\001\073\001\076\001\
\075\001\076\001\077\001\000\000\055\001\073\001\230\000\070\001\
\232\000\001\001\073\001\113\001\183\002\176\001\006\001\000\001\
\001\001\180\001\223\001\224\001\089\002\006\001\069\001\070\001\
\075\001\070\001\073\001\190\001\191\001\192\001\077\001\055\001\
\071\001\118\001\072\001\104\002\113\001\072\001\077\001\071\001\
\069\001\070\001\001\001\118\001\073\001\001\001\171\001\006\001\
\077\001\074\001\006\001\222\002\077\001\001\001\185\000\186\000\
\187\000\188\000\189\000\190\000\000\001\106\002\030\001\049\001\
\050\001\051\001\052\001\070\001\036\001\232\001\055\001\118\001\
\134\001\135\001\185\001\072\001\001\001\001\001\070\001\096\001\
\097\001\006\001\006\001\208\001\069\001\070\001\070\001\036\002\
\073\001\001\001\075\001\076\001\077\001\001\001\006\001\070\001\
\069\001\001\001\006\001\067\001\049\002\069\001\075\001\184\001\
\000\001\174\001\001\001\055\001\070\001\069\001\078\001\070\001\
\210\001\069\001\070\001\075\001\070\001\073\001\187\001\087\001\
\088\001\077\001\070\001\072\001\074\001\074\002\118\001\077\001\
\076\001\043\002\055\001\055\001\072\001\118\001\091\002\092\002\
\076\001\077\001\168\002\055\001\056\001\057\001\001\001\070\002\
\069\001\070\001\070\001\006\001\073\001\073\001\070\001\072\001\
\077\001\073\001\171\001\192\001\025\002\069\001\070\001\118\001\
\034\001\073\001\118\001\032\002\072\001\077\001\069\001\072\001\
\095\002\069\001\118\001\059\001\075\001\073\001\071\001\124\002\
\075\001\077\001\127\002\076\001\095\000\096\000\051\002\063\001\
\064\001\134\002\071\001\095\001\000\001\069\001\061\001\076\001\
\075\001\118\001\118\001\069\001\076\001\077\001\001\000\002\000\
\108\001\075\001\076\001\077\001\060\001\060\002\118\001\062\002\
\063\001\064\001\118\001\179\001\024\001\072\001\069\001\027\001\
\028\001\185\001\063\001\031\001\089\002\076\001\077\001\069\001\
\024\001\057\002\064\001\027\001\074\001\075\001\076\001\037\002\
\101\002\113\001\183\002\104\002\077\001\106\002\001\001\114\001\
\115\001\116\001\117\001\118\001\119\001\120\001\121\001\122\001\
\123\001\124\001\125\001\126\001\127\001\128\001\129\001\130\001\
\131\001\070\002\113\001\118\001\076\001\168\002\075\001\024\002\
\034\001\078\001\101\001\070\002\183\000\184\000\055\001\056\001\
\057\001\222\002\045\001\046\001\077\001\192\000\193\000\134\002\
\053\001\054\001\076\001\095\001\024\001\065\001\066\001\027\001\
\028\001\100\002\076\001\031\001\095\002\162\002\047\001\048\001\
\108\001\069\001\110\001\055\001\024\001\053\001\054\001\027\001\
\028\001\000\001\001\001\031\001\177\002\004\001\077\001\006\001\
\007\001\034\001\024\001\065\001\066\001\027\001\028\001\047\001\
\048\001\031\001\049\001\050\001\051\001\052\001\000\001\001\001\
\089\002\024\001\070\001\144\002\027\001\073\001\092\001\093\001\
\069\001\032\001\033\001\076\001\077\001\077\001\000\001\104\002\
\076\001\077\001\070\001\001\001\060\002\073\001\062\002\226\001\
\117\001\118\001\186\002\095\001\072\001\097\001\053\001\054\001\
\055\001\073\002\076\001\058\001\059\001\071\001\235\002\062\001\
\108\001\072\001\110\001\095\001\071\001\097\001\069\001\070\001\
\034\001\137\002\138\002\091\002\092\002\213\002\125\001\126\001\
\108\001\095\001\110\001\097\001\100\002\024\001\072\001\086\001\
\027\001\028\001\119\001\120\001\031\001\069\001\108\001\111\002\
\110\001\249\000\250\000\024\001\099\001\100\001\027\001\028\001\
\069\001\000\001\031\001\069\001\251\000\252\000\072\001\001\001\
\002\001\075\001\076\001\077\001\226\002\001\001\134\002\121\001\
\122\001\123\001\124\001\070\001\000\001\001\001\236\002\070\001\
\238\002\145\002\006\001\070\001\070\001\009\001\010\001\011\001\
\012\001\013\001\014\001\034\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\095\001\134\001\135\001\070\001\
\064\001\253\000\254\000\255\000\000\001\069\001\069\001\069\001\
\059\001\108\001\095\001\110\001\076\001\077\001\069\001\061\001\
\099\002\072\001\060\001\055\001\075\001\076\001\077\001\108\001\
\063\001\110\001\060\001\061\001\077\001\063\001\064\001\069\001\
\004\001\069\001\070\001\069\001\004\001\073\001\069\001\075\001\
\076\001\077\001\076\001\077\001\004\001\045\001\046\001\113\001\
\069\001\113\001\071\001\071\001\071\001\074\001\075\001\076\001\
\077\001\078\001\071\001\095\001\096\001\069\001\098\001\069\001\
\001\001\105\001\071\001\067\001\068\001\076\001\070\001\069\001\
\108\001\073\001\110\001\000\001\001\001\069\001\075\001\113\001\
\116\001\006\001\118\001\077\001\009\001\010\001\011\001\012\001\
\013\001\014\001\071\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\045\001\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\054\001\055\001\056\001\057\001\
\071\001\059\001\060\001\061\001\071\001\063\001\064\001\065\001\
\066\001\071\001\055\001\069\001\071\001\076\001\069\001\069\001\
\077\001\060\001\076\001\077\001\063\001\064\001\069\001\001\001\
\069\001\070\001\069\001\069\001\073\001\070\001\075\001\076\001\
\077\001\076\001\077\001\069\001\001\001\001\001\070\001\077\001\
\076\001\076\001\059\001\060\001\061\001\073\001\063\001\064\001\
\071\001\071\001\095\001\096\001\069\001\098\001\071\001\113\001\
\071\001\074\001\075\001\076\001\077\001\078\001\079\001\108\001\
\071\001\110\001\000\001\001\001\069\001\069\001\113\001\116\001\
\006\001\118\001\069\001\009\001\010\001\011\001\012\001\013\001\
\014\001\077\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\045\001\046\001\047\001\048\001\049\001\050\001\
\051\001\052\001\053\001\054\001\055\001\056\001\057\001\077\001\
\059\001\060\001\061\001\077\001\063\001\064\001\065\001\066\001\
\064\001\055\001\069\001\069\001\077\001\069\001\069\001\075\001\
\077\001\076\001\077\001\072\001\076\001\077\001\074\001\069\001\
\070\001\072\001\077\001\073\001\072\001\075\001\076\001\077\001\
\034\001\000\001\001\001\002\001\003\001\004\001\005\001\006\001\
\007\001\008\001\075\001\071\001\069\001\069\001\069\001\076\001\
\075\001\095\001\096\001\070\001\098\001\075\001\113\001\076\001\
\070\001\113\001\076\001\071\001\077\001\076\001\108\001\069\001\
\110\001\032\001\033\001\034\001\047\001\048\001\116\001\071\001\
\118\001\001\001\069\001\074\001\087\001\070\001\076\001\076\001\
\059\001\060\001\061\001\075\001\063\001\064\001\053\001\054\001\
\055\001\069\001\069\001\058\001\059\001\069\001\071\001\062\001\
\063\001\076\001\077\001\074\001\067\001\068\001\069\001\070\001\
\069\001\072\001\073\001\074\001\075\001\076\001\077\001\069\001\
\071\001\059\001\060\001\061\001\071\001\063\001\064\001\076\001\
\076\001\094\001\007\001\069\001\001\001\074\001\076\001\075\001\
\069\001\076\001\076\001\077\001\099\001\100\001\113\001\102\001\
\075\001\069\001\075\001\106\001\107\001\070\001\077\001\076\001\
\069\001\069\001\077\001\069\001\075\001\000\001\117\001\118\001\
\000\001\001\001\002\001\003\001\004\001\005\001\006\001\007\001\
\008\001\009\001\010\001\011\001\012\001\013\001\014\001\113\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\076\001\047\001\048\001\049\001\050\001\051\001\
\052\001\071\001\069\001\069\001\076\001\069\001\071\001\059\001\
\060\001\061\001\073\001\063\001\064\001\053\001\054\001\055\001\
\071\001\069\001\058\001\059\001\071\001\069\001\062\001\063\001\
\076\001\077\001\075\001\067\001\068\001\071\001\070\001\071\001\
\072\001\071\001\071\001\076\001\076\001\070\001\074\001\071\001\
\080\001\081\001\082\001\083\001\084\001\085\001\086\001\087\001\
\088\001\089\001\090\001\091\001\076\001\076\001\069\001\095\001\
\096\001\097\001\098\001\099\001\100\001\113\001\102\001\069\001\
\069\001\105\001\106\001\107\001\108\001\109\001\110\001\069\001\
\002\000\121\000\180\001\040\001\116\001\117\001\000\001\001\001\
\002\001\003\001\004\001\005\001\006\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\155\002\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\017\001\047\001\048\001\049\001\050\001\051\001\052\001\161\002\
\041\002\040\002\209\001\133\000\127\001\059\001\060\001\061\001\
\128\001\063\001\064\001\053\001\054\001\055\001\129\001\069\001\
\058\001\059\001\130\001\216\002\062\001\063\001\076\001\077\001\
\131\001\067\001\068\001\099\002\070\001\071\001\072\001\074\002\
\003\001\005\001\076\001\004\001\195\001\007\001\080\001\081\001\
\082\001\083\001\084\001\085\001\086\001\087\001\088\001\089\001\
\090\001\091\001\144\002\006\001\236\002\095\001\096\001\097\001\
\098\001\099\001\100\001\113\001\102\001\238\002\251\002\255\255\
\106\001\107\001\108\001\109\001\110\001\255\255\255\255\255\255\
\255\255\255\255\116\001\117\001\000\001\001\001\002\001\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\255\255\047\001\
\048\001\049\001\050\001\051\001\052\001\255\255\255\255\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\053\001\054\001\055\001\255\255\069\001\058\001\059\001\
\255\255\255\255\062\001\063\001\076\001\077\001\255\255\067\001\
\068\001\255\255\070\001\071\001\072\001\255\255\255\255\255\255\
\076\001\255\255\255\255\255\255\080\001\081\001\082\001\083\001\
\084\001\085\001\086\001\087\001\088\001\089\001\090\001\091\001\
\255\255\255\255\255\255\095\001\096\001\097\001\098\001\099\001\
\100\001\113\001\102\001\255\255\255\255\255\255\106\001\107\001\
\108\001\109\001\110\001\255\255\255\255\255\255\255\255\255\255\
\116\001\117\001\000\001\001\001\002\001\003\001\004\001\005\001\
\006\001\007\001\008\001\009\001\010\001\011\001\012\001\013\001\
\014\001\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\255\255\047\001\048\001\049\001\
\050\001\051\001\052\001\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\063\001\064\001\053\001\
\054\001\055\001\255\255\069\001\058\001\059\001\255\255\255\255\
\062\001\063\001\076\001\077\001\255\255\067\001\068\001\255\255\
\070\001\255\255\072\001\255\255\255\255\255\255\076\001\255\255\
\255\255\255\255\080\001\081\001\082\001\083\001\084\001\085\001\
\086\001\087\001\088\001\089\001\090\001\091\001\255\255\255\255\
\255\255\095\001\096\001\097\001\098\001\099\001\100\001\113\001\
\102\001\255\255\255\255\255\255\106\001\107\001\108\001\109\001\
\110\001\255\255\255\255\255\255\255\255\255\255\116\001\117\001\
\000\001\001\001\002\001\003\001\004\001\005\001\006\001\007\001\
\008\001\009\001\010\001\011\001\012\001\013\001\014\001\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\053\001\054\001\055\001\
\255\255\069\001\058\001\059\001\255\255\255\255\062\001\063\001\
\076\001\077\001\064\001\067\001\068\001\255\255\070\001\069\001\
\072\001\071\001\255\255\014\000\074\001\075\001\076\001\077\001\
\078\001\079\001\255\255\022\000\255\255\255\255\025\000\026\000\
\255\255\255\255\255\255\030\000\255\255\255\255\255\255\095\001\
\096\001\255\255\098\001\099\001\100\001\113\001\102\001\255\255\
\255\255\255\255\106\001\107\001\108\001\255\255\110\001\050\000\
\051\000\255\255\255\255\255\255\116\001\117\001\000\001\001\001\
\002\001\003\001\004\001\005\001\006\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\255\255\047\001\048\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\053\001\054\001\055\001\255\255\069\001\
\058\001\059\001\255\255\255\255\062\001\063\001\076\001\077\001\
\255\255\067\001\068\001\255\255\070\001\000\001\001\001\002\001\
\003\001\004\001\005\001\064\001\007\001\008\001\255\255\255\255\
\069\001\255\255\071\001\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\255\255\255\255\095\001\096\001\255\255\
\098\001\099\001\100\001\113\001\102\001\032\001\033\001\255\255\
\106\001\107\001\108\001\255\255\110\001\255\255\255\255\255\255\
\255\255\255\255\116\001\117\001\059\001\060\001\061\001\255\255\
\063\001\064\001\053\001\054\001\055\001\255\255\069\001\058\001\
\059\001\255\255\255\255\062\001\063\001\076\001\077\001\255\255\
\067\001\068\001\255\255\070\001\255\255\072\001\255\255\255\255\
\255\255\076\001\255\255\255\255\255\255\080\001\081\001\082\001\
\083\001\084\001\085\001\086\001\087\001\088\001\089\001\090\001\
\091\001\255\255\255\255\255\255\255\255\255\255\097\001\255\255\
\099\001\100\001\113\001\102\001\255\255\255\255\255\255\106\001\
\107\001\255\255\109\001\255\255\255\255\255\255\255\255\255\255\
\047\001\048\001\117\001\001\001\002\001\003\001\004\001\005\001\
\006\001\007\001\008\001\255\255\059\001\060\001\061\001\255\255\
\063\001\064\001\255\255\255\255\255\255\255\255\069\001\255\255\
\255\255\255\255\255\255\255\255\255\255\076\001\077\001\255\255\
\255\255\255\255\032\001\033\001\001\001\255\255\255\255\004\001\
\255\255\006\001\007\001\255\255\255\255\255\255\255\255\255\255\
\046\001\255\255\255\255\255\255\255\255\255\255\255\255\053\001\
\054\001\055\001\255\255\024\001\058\001\059\001\027\001\255\255\
\062\001\063\001\113\001\032\001\033\001\067\001\068\001\255\255\
\070\001\255\255\072\001\073\001\255\255\255\255\000\001\001\001\
\002\001\003\001\004\001\005\001\255\255\007\001\008\001\255\255\
\053\001\054\001\055\001\255\255\255\255\058\001\059\001\255\255\
\255\255\062\001\255\255\255\255\255\255\099\001\100\001\255\255\
\102\001\070\001\255\255\255\255\106\001\107\001\032\001\033\001\
\255\255\060\001\061\001\255\255\063\001\064\001\255\255\117\001\
\118\001\086\001\069\001\255\255\255\255\255\255\255\255\255\255\
\255\255\076\001\077\001\053\001\054\001\055\001\099\001\100\001\
\058\001\059\001\255\255\255\255\062\001\063\001\255\255\255\255\
\255\255\067\001\068\001\255\255\070\001\255\255\255\255\255\255\
\255\255\255\255\076\001\000\001\001\001\002\001\003\001\004\001\
\005\001\255\255\007\001\008\001\255\255\255\255\113\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\099\001\100\001\255\255\102\001\255\255\255\255\255\255\
\106\001\107\001\255\255\032\001\033\001\060\001\255\255\255\255\
\063\001\064\001\255\255\117\001\255\255\255\255\069\001\255\255\
\255\255\255\255\255\255\255\255\255\255\076\001\077\001\255\255\
\053\001\054\001\055\001\255\255\255\255\058\001\059\001\255\255\
\255\255\062\001\063\001\255\255\255\255\255\255\067\001\068\001\
\255\255\070\001\255\255\255\255\255\255\074\001\255\255\000\001\
\001\001\002\001\003\001\004\001\005\001\255\255\007\001\008\001\
\255\255\255\255\113\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\099\001\100\001\
\255\255\102\001\255\255\255\255\255\255\106\001\107\001\032\001\
\033\001\063\001\064\001\255\255\255\255\255\255\255\255\069\001\
\117\001\071\001\255\255\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\255\255\255\255\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\000\001\001\001\
\002\001\003\001\004\001\005\001\255\255\007\001\008\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\000\001\001\001\002\001\003\001\004\001\005\001\255\255\
\007\001\008\001\099\001\100\001\255\255\102\001\032\001\033\001\
\255\255\106\001\107\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\117\001\255\255\255\255\255\255\
\255\255\032\001\033\001\053\001\054\001\055\001\255\255\255\255\
\058\001\059\001\255\255\255\255\062\001\063\001\255\255\255\255\
\255\255\067\001\068\001\255\255\070\001\255\255\053\001\054\001\
\055\001\255\255\255\255\058\001\059\001\255\255\255\255\062\001\
\063\001\255\255\255\255\255\255\067\001\068\001\255\255\070\001\
\000\001\001\001\002\001\003\001\004\001\005\001\255\255\007\001\
\008\001\099\001\100\001\255\255\102\001\255\255\255\255\255\255\
\106\001\107\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\117\001\099\001\100\001\255\255\102\001\
\032\001\033\001\255\255\106\001\107\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\117\001\255\255\
\255\255\255\255\255\255\255\255\255\255\053\001\054\001\055\001\
\255\255\255\255\058\001\059\001\255\255\255\255\062\001\063\001\
\255\255\255\255\255\255\067\001\068\001\255\255\070\001\000\001\
\001\001\002\001\003\001\004\001\005\001\060\001\007\001\008\001\
\063\001\064\001\255\255\255\255\255\255\255\255\069\001\255\255\
\071\001\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\255\255\255\255\099\001\100\001\255\255\102\001\032\001\
\033\001\255\255\106\001\107\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\117\001\255\255\255\255\
\255\255\255\255\255\255\255\255\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\047\001\048\001\049\001\050\001\051\001\052\001\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\063\001\064\001\099\001\100\001\255\255\102\001\069\001\255\255\
\071\001\106\001\107\001\074\001\075\001\076\001\077\001\078\001\
\079\001\255\255\255\255\255\255\117\001\001\001\002\001\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\063\001\064\001\
\255\255\255\255\255\255\255\255\069\001\255\255\071\001\255\255\
\255\255\074\001\075\001\076\001\077\001\078\001\079\001\255\255\
\255\255\053\001\054\001\055\001\255\255\255\255\058\001\059\001\
\255\255\255\255\062\001\063\001\255\255\255\255\255\255\067\001\
\068\001\255\255\070\001\255\255\255\255\255\255\255\255\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\065\001\066\001\095\001\096\001\069\001\098\001\099\001\
\100\001\255\255\102\001\255\255\076\001\077\001\106\001\107\001\
\108\001\000\001\110\001\255\255\255\255\255\255\255\255\006\001\
\116\001\117\001\009\001\010\001\011\001\012\001\013\001\014\001\
\255\255\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\113\001\059\001\060\001\061\001\255\255\063\001\064\001\
\255\255\255\255\255\255\255\255\069\001\255\255\071\001\255\255\
\255\255\074\001\075\001\076\001\077\001\078\001\079\001\255\255\
\255\255\047\001\048\001\255\255\255\255\001\001\002\001\003\001\
\004\001\005\001\255\255\007\001\008\001\059\001\060\001\061\001\
\255\255\063\001\064\001\255\255\255\255\076\001\255\255\069\001\
\255\255\071\001\255\255\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\255\255\255\255\032\001\033\001\034\001\255\255\
\095\001\096\001\255\255\098\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\108\001\255\255\110\001\
\255\255\053\001\054\001\055\001\255\255\116\001\058\001\059\001\
\255\255\255\255\062\001\063\001\255\255\255\255\255\255\067\001\
\068\001\255\255\070\001\255\255\072\001\001\001\002\001\003\001\
\004\001\005\001\060\001\007\001\008\001\063\001\064\001\255\255\
\255\255\255\255\255\255\069\001\255\255\071\001\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\255\255\099\001\
\100\001\255\255\102\001\255\255\032\001\033\001\106\001\107\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\117\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\053\001\054\001\055\001\255\255\255\255\058\001\059\001\
\255\255\255\255\062\001\063\001\255\255\255\255\255\255\067\001\
\068\001\255\255\070\001\255\255\072\001\001\001\002\001\003\001\
\004\001\005\001\255\255\007\001\008\001\103\001\104\001\105\001\
\106\001\107\001\108\001\109\001\110\001\111\001\112\001\113\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\099\001\
\100\001\255\255\102\001\255\255\032\001\033\001\106\001\107\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\117\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\053\001\054\001\055\001\255\255\255\255\058\001\059\001\
\255\255\255\255\062\001\063\001\255\255\255\255\255\255\067\001\
\068\001\255\255\070\001\255\255\072\001\001\001\002\001\003\001\
\004\001\005\001\255\255\007\001\008\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\099\001\
\100\001\255\255\102\001\255\255\032\001\033\001\106\001\107\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\117\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\053\001\054\001\055\001\255\255\255\255\058\001\059\001\
\255\255\255\255\062\001\063\001\255\255\255\255\255\255\067\001\
\068\001\255\255\070\001\255\255\072\001\001\001\002\001\003\001\
\004\001\005\001\255\255\007\001\008\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\099\001\
\100\001\255\255\102\001\255\255\032\001\033\001\106\001\107\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\117\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\053\001\054\001\055\001\255\255\255\255\058\001\059\001\
\255\255\255\255\062\001\063\001\255\255\255\255\255\255\067\001\
\068\001\255\255\070\001\255\255\001\001\002\001\003\001\004\001\
\005\001\255\255\007\001\008\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\001\001\
\002\001\003\001\004\001\005\001\255\255\007\001\008\001\099\001\
\100\001\255\255\102\001\032\001\033\001\255\255\106\001\107\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\117\001\255\255\255\255\255\255\255\255\032\001\033\001\
\053\001\054\001\055\001\255\255\255\255\058\001\059\001\255\255\
\255\255\062\001\063\001\255\255\255\255\255\255\067\001\068\001\
\255\255\070\001\255\255\053\001\054\001\055\001\255\255\255\255\
\058\001\059\001\255\255\255\255\062\001\063\001\255\255\255\255\
\255\255\067\001\068\001\255\255\070\001\255\255\001\001\002\001\
\003\001\004\001\005\001\255\255\007\001\008\001\099\001\100\001\
\255\255\102\001\255\255\255\255\255\255\106\001\107\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\117\001\099\001\100\001\255\255\102\001\032\001\033\001\255\255\
\106\001\107\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\117\001\255\255\255\255\255\255\255\255\
\255\255\255\255\053\001\054\001\055\001\255\255\255\255\058\001\
\059\001\255\255\255\255\062\001\063\001\255\255\255\255\255\255\
\067\001\068\001\255\255\070\001\255\255\001\001\002\001\003\001\
\004\001\005\001\255\255\007\001\008\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\001\001\002\001\003\001\004\001\005\001\255\255\007\001\008\001\
\099\001\100\001\255\255\102\001\032\001\033\001\255\255\106\001\
\107\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\117\001\255\255\255\255\255\255\255\255\032\001\
\033\001\053\001\054\001\055\001\255\255\255\255\058\001\059\001\
\255\255\255\255\062\001\063\001\255\255\255\255\255\255\067\001\
\068\001\255\255\070\001\255\255\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\255\255\255\255\
\255\255\255\255\060\001\061\001\255\255\063\001\064\001\099\001\
\100\001\255\255\102\001\069\001\255\255\071\001\106\001\107\001\
\074\001\075\001\076\001\077\001\078\001\079\001\255\255\255\255\
\255\255\117\001\099\001\100\001\255\255\102\001\001\001\255\255\
\255\255\106\001\107\001\006\001\255\255\255\255\009\001\010\001\
\011\001\012\001\013\001\014\001\117\001\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\001\001\255\255\255\255\
\255\255\255\255\006\001\255\255\255\255\009\001\010\001\011\001\
\012\001\013\001\014\001\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\076\001\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\065\001\066\001\255\255\
\255\255\069\001\255\255\255\255\095\001\096\001\097\001\098\001\
\076\001\077\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\108\001\255\255\110\001\111\001\112\001\255\255\114\001\
\115\001\116\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\095\001\096\001\097\001\098\001\255\255\
\255\255\255\255\255\255\255\255\255\255\113\001\255\255\255\255\
\108\001\255\255\110\001\111\001\112\001\255\255\114\001\115\001\
\116\001\006\001\255\255\255\255\009\001\010\001\011\001\012\001\
\013\001\014\001\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\255\255\255\255\034\001\035\001\036\001\
\037\001\038\001\039\001\040\001\041\001\042\001\043\001\044\001\
\045\001\046\001\047\001\048\001\049\001\050\001\051\001\052\001\
\053\001\054\001\055\001\056\001\057\001\255\255\059\001\060\001\
\061\001\255\255\063\001\064\001\065\001\066\001\067\001\068\001\
\069\001\070\001\071\001\072\001\073\001\074\001\075\001\076\001\
\077\001\078\001\079\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\060\001\061\001\255\255\063\001\064\001\
\255\255\255\255\095\001\096\001\069\001\098\001\071\001\255\255\
\255\255\074\001\075\001\076\001\077\001\078\001\079\001\108\001\
\255\255\110\001\255\255\255\255\113\001\006\001\007\001\116\001\
\009\001\010\001\011\001\012\001\013\001\014\001\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\255\255\
\006\001\255\255\255\255\009\001\010\001\011\001\012\001\013\001\
\014\001\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\255\255\255\255\255\255\255\255\006\001\255\255\
\255\255\009\001\010\001\011\001\012\001\013\001\014\001\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\255\255\255\255\255\255\255\255\255\255\255\255\095\001\096\001\
\070\001\098\001\099\001\100\001\255\255\255\255\255\255\255\255\
\078\001\255\255\255\255\108\001\255\255\110\001\255\255\255\255\
\255\255\255\255\255\255\116\001\047\001\048\001\255\255\255\255\
\255\255\095\001\096\001\255\255\098\001\069\001\070\001\255\255\
\059\001\060\001\061\001\255\255\063\001\064\001\108\001\255\255\
\110\001\255\255\069\001\255\255\071\001\255\255\116\001\074\001\
\075\001\076\001\077\001\078\001\079\001\255\255\255\255\095\001\
\096\001\255\255\098\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\108\001\255\255\110\001\255\255\
\255\255\255\255\006\001\255\255\116\001\009\001\010\001\011\001\
\012\001\013\001\014\001\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\255\255\006\001\255\255\255\255\
\009\001\010\001\011\001\012\001\013\001\014\001\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\255\255\
\255\255\006\001\255\255\255\255\009\001\010\001\011\001\012\001\
\013\001\014\001\070\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\095\001\096\001\255\255\098\001\072\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\108\001\255\255\110\001\255\255\255\255\255\255\255\255\255\255\
\116\001\255\255\255\255\255\255\255\255\255\255\095\001\096\001\
\255\255\098\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\078\001\255\255\108\001\255\255\110\001\255\255\255\255\
\255\255\255\255\255\255\116\001\255\255\255\255\255\255\255\255\
\255\255\255\255\095\001\096\001\255\255\098\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\108\001\
\255\255\110\001\255\255\255\255\255\255\006\001\255\255\116\001\
\009\001\010\001\011\001\012\001\013\001\014\001\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\009\001\
\010\001\011\001\012\001\013\001\014\001\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\000\001\001\001\255\255\
\255\255\004\001\255\255\006\001\007\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\024\001\095\001\096\001\
\027\001\098\001\255\255\255\255\255\255\032\001\033\001\255\255\
\255\255\255\255\255\255\108\001\255\255\110\001\255\255\255\255\
\255\255\255\255\255\255\116\001\255\255\095\001\096\001\255\255\
\098\001\255\255\053\001\054\001\055\001\255\255\255\255\058\001\
\059\001\255\255\108\001\062\001\110\001\255\255\255\255\255\255\
\255\255\255\255\116\001\070\001\000\001\001\001\255\255\255\255\
\004\001\255\255\006\001\007\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\024\001\255\255\255\255\027\001\
\099\001\100\001\255\255\255\255\032\001\033\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\053\001\054\001\055\001\255\255\255\255\058\001\059\001\
\255\255\255\255\062\001\047\001\048\001\049\001\050\001\051\001\
\052\001\255\255\070\001\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\065\001\066\001\255\255\
\255\255\069\001\086\001\255\255\255\255\255\255\255\255\255\255\
\076\001\077\001\255\255\255\255\255\255\255\255\255\255\099\001\
\100\001\034\001\035\001\036\001\037\001\038\001\039\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\255\255\059\001\060\001\061\001\113\001\063\001\064\001\
\065\001\066\001\067\001\068\001\069\001\070\001\071\001\255\255\
\073\001\074\001\075\001\076\001\077\001\078\001\079\001\034\001\
\035\001\036\001\037\001\038\001\039\001\040\001\041\001\042\001\
\043\001\044\001\255\255\255\255\047\001\048\001\049\001\050\001\
\051\001\052\001\053\001\054\001\055\001\056\001\057\001\255\255\
\059\001\060\001\061\001\255\255\063\001\064\001\065\001\066\001\
\113\001\255\255\069\001\255\255\071\001\255\255\255\255\074\001\
\075\001\076\001\077\001\078\001\079\001\034\001\035\001\036\001\
\037\001\038\001\039\001\040\001\041\001\042\001\043\001\044\001\
\255\255\255\255\047\001\048\001\049\001\050\001\051\001\052\001\
\053\001\054\001\055\001\056\001\057\001\255\255\059\001\060\001\
\061\001\255\255\063\001\064\001\065\001\066\001\113\001\255\255\
\069\001\255\255\071\001\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\255\255\255\255\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\054\001\
\055\001\056\001\057\001\255\255\059\001\060\001\061\001\255\255\
\063\001\064\001\065\001\066\001\113\001\255\255\069\001\255\255\
\071\001\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\065\001\066\001\255\255\255\255\069\001\
\255\255\255\255\255\255\255\255\255\255\255\255\076\001\077\001\
\255\255\255\255\113\001\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\054\001\055\001\056\001\057\001\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\065\001\066\001\255\255\
\255\255\069\001\255\255\255\255\255\255\255\255\255\255\255\255\
\076\001\077\001\255\255\113\001\047\001\048\001\049\001\050\001\
\051\001\052\001\053\001\054\001\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\063\001\064\001\065\001\066\001\
\255\255\255\255\069\001\255\255\255\255\255\255\255\255\255\255\
\255\255\076\001\077\001\255\255\255\255\113\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\065\001\066\001\255\255\255\255\069\001\255\255\255\255\255\255\
\255\255\255\255\255\255\076\001\077\001\255\255\113\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\065\001\066\001\255\255\255\255\069\001\047\001\048\001\
\049\001\050\001\051\001\052\001\076\001\077\001\255\255\255\255\
\113\001\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\065\001\066\001\255\255\255\255\069\001\255\255\255\255\255\255\
\255\255\255\255\255\255\076\001\077\001\255\255\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\113\001\059\001\060\001\061\001\255\255\063\001\064\001\
\065\001\066\001\255\255\255\255\069\001\255\255\071\001\255\255\
\255\255\074\001\075\001\076\001\077\001\078\001\079\001\255\255\
\113\001\034\001\035\001\036\001\037\001\038\001\039\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\065\001\066\001\067\001\068\001\255\255\070\001\071\001\255\255\
\073\001\255\255\075\001\255\255\077\001\255\255\079\001\034\001\
\035\001\036\001\037\001\038\001\039\001\040\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\050\001\
\051\001\052\001\053\001\054\001\055\001\056\001\057\001\255\255\
\059\001\060\001\061\001\255\255\063\001\064\001\065\001\066\001\
\067\001\068\001\255\255\070\001\255\255\255\255\073\001\255\255\
\255\255\076\001\077\001\255\255\079\001\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\054\001\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\063\001\064\001\065\001\
\066\001\255\255\255\255\069\001\255\255\071\001\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\065\001\066\001\255\255\255\255\069\001\255\255\071\001\255\255\
\255\255\074\001\075\001\076\001\077\001\078\001\079\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\065\001\066\001\255\255\255\255\069\001\255\255\071\001\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\079\001\
\047\001\048\001\049\001\050\001\051\001\052\001\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\063\001\064\001\065\001\066\001\255\255\255\255\069\001\255\255\
\071\001\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\047\001\048\001\049\001\050\001\051\001\052\001\255\255\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\065\001\066\001\255\255\255\255\069\001\
\255\255\071\001\255\255\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\047\001\048\001\049\001\050\001\051\001\052\001\
\255\255\255\255\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\063\001\064\001\065\001\066\001\255\255\255\255\
\069\001\255\255\071\001\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\047\001\048\001\049\001\050\001\051\001\
\052\001\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\255\255\255\255\255\255\
\255\255\069\001\255\255\071\001\255\255\255\255\074\001\075\001\
\076\001\077\001\078\001\079\001\047\001\048\001\049\001\050\001\
\051\001\052\001\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\063\001\064\001\255\255\255\255\
\255\255\255\255\069\001\255\255\071\001\255\255\255\255\074\001\
\075\001\076\001\077\001\078\001\079\001\047\001\048\001\049\001\
\050\001\051\001\052\001\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\063\001\064\001\255\255\
\255\255\255\255\255\255\069\001\255\255\071\001\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\047\001\048\001\
\049\001\050\001\051\001\052\001\255\255\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\255\255\255\255\255\255\255\255\069\001\255\255\071\001\047\001\
\048\001\074\001\075\001\076\001\077\001\078\001\079\001\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\255\255\255\255\255\255\255\255\069\001\255\255\071\001\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\079\001"

let yynames_const = "\
  EOF\000\
  EQ\000\
  PLUS_EQ\000\
  MINUS_EQ\000\
  STAR_EQ\000\
  SLASH_EQ\000\
  PERCENT_EQ\000\
  AND_EQ\000\
  PIPE_EQ\000\
  CIRC_EQ\000\
  INF_INF_EQ\000\
  SUP_SUP_EQ\000\
  ARROW\000\
  DOT\000\
  EQ_EQ\000\
  EXCLAM_EQ\000\
  INF\000\
  SUP\000\
  INF_EQ\000\
  SUP_EQ\000\
  SLASH\000\
  PERCENT\000\
  PIPE\000\
  CIRC\000\
  PIPE_PIPE\000\
  INF_INF\000\
  SUP_SUP\000\
  RPAREN\000\
  LBRACKET\000\
  RBRACKET\000\
  COLON\000\
  COMMA\000\
  ELLIPSIS\000\
  QUEST\000\
  ELSE\000\
  LABEL__\000\
  BUILTIN_VA_LIST\000\
  BLOCKATTRIBUTE\000\
  PRAGMA_EOL\000\
  AT_NAME\000\
  "

let yynames_block = "\
  IDENT\000\
  CST_CHAR\000\
  CST_WCHAR\000\
  CST_INT\000\
  CST_FLOAT\000\
  NAMED_TYPE\000\
  CST_STRING\000\
  CST_WSTRING\000\
  CHAR\000\
  INT\000\
  DOUBLE\000\
  FLOAT\000\
  VOID\000\
  INT64\000\
  INT32\000\
  ENUM\000\
  STRUCT\000\
  TYPEDEF\000\
  UNION\000\
  SIGNED\000\
  UNSIGNED\000\
  LONG\000\
  SHORT\000\
  VOLATILE\000\
  EXTERN\000\
  STATIC\000\
  CONST\000\
  RESTRICT\000\
  AUTO\000\
  REGISTER\000\
  THREAD\000\
  SIZEOF\000\
  ALIGNOF\000\
  PLUS\000\
  MINUS\000\
  STAR\000\
  TILDE\000\
  AND\000\
  EXCLAM\000\
  AND_AND\000\
  PLUS_PLUS\000\
  MINUS_MINUS\000\
  LPAREN\000\
  RBRACE\000\
  LBRACE\000\
  SEMICOLON\000\
  BREAK\000\
  CONTINUE\000\
  GOTO\000\
  RETURN\000\
  SWITCH\000\
  CASE\000\
  DEFAULT\000\
  WHILE\000\
  DO\000\
  FOR\000\
  IF\000\
  TRY\000\
  EXCEPT\000\
  FINALLY\000\
  ATTRIBUTE\000\
  INLINE\000\
  ASM\000\
  TYPEOF\000\
  FUNCTION__\000\
  PRETTY_FUNCTION__\000\
  BUILTIN_VA_ARG\000\
  ATTRIBUTE_USED\000\
  BUILTIN_TYPES_COMPAT\000\
  BUILTIN_OFFSETOF\000\
  DECLSPEC\000\
  MSASM\000\
  MSATTR\000\
  PRAGMA\000\
  PRAGMA_LINE\000\
  AT_TRANSFORM\000\
  AT_TRANSFORMEXPR\000\
  AT_SPECIFIER\000\
  AT_EXPR\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition list) in
    Obj.repr(
# 376 "src/frontc/cparser.mly"
              (_1)
# 2247 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 378 "src/frontc/cparser.mly"
                 (_1)
# 2254 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    Obj.repr(
# 381 "src/frontc/cparser.mly"
                                        ( [] )
# 2260 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 382 "src/frontc/cparser.mly"
                                        ( _1 :: _2 )
# 2268 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 383 "src/frontc/cparser.mly"
                                        ( _2 )
# 2276 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun __caml_parser_env ->
    Obj.repr(
# 387 "src/frontc/cparser.mly"
                               ( currentLoc () )
# 2282 "src/frontc/cparser.ml"
               : Cabs.cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 392 "src/frontc/cparser.mly"
                                        ( _1 )
# 2289 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 393 "src/frontc/cparser.mly"
                                        ( _1 )
# 2296 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 396 "src/frontc/cparser.mly"
                                        ( LINKAGE (fst _2, snd _2, [ _3 ]) )
# 2305 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 398 "src/frontc/cparser.mly"
                                        ( LINKAGE (fst _2, snd _2, _4)  )
# 2316 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 400 "src/frontc/cparser.mly"
                                        ( GLOBASM (fst _3, _1) )
# 2326 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 401 "src/frontc/cparser.mly"
                          ( PRAGMA (_2, _1) )
# 2334 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 402 "src/frontc/cparser.mly"
                                   ( PRAGMA (_2, _1) )
# 2343 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 403 "src/frontc/cparser.mly"
                                        ( PRAGMA (VARIABLE (fst _1), 
                                                  snd _1) )
# 2351 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'old_pardef_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 409 "src/frontc/cparser.mly"
                           ( (* Convert pardecl to new style *)
                             let pardecl, isva = doOldParDecl _3 _5 in 
                             (* Make the function declarator *)
                             doDeclaration (snd _1) []
                               [((fst _1, PROTO(JUSTBASE, pardecl,isva), [], cabslu),
                                 NO_INIT)]
                            )
# 2368 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 418 "src/frontc/cparser.mly"
                           ( (* Make the function declarator *)
                             doDeclaration (snd _1) []
                               [((fst _1, PROTO(JUSTBASE,[],false), [], cabslu),
                                 NO_INIT)]
                            )
# 2381 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : Cabs.definition) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition list) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 424 "src/frontc/cparser.mly"
                                                                        (
    checkConnective(fst _5);
    TRANSFORMER(_3, _7, _1)
  )
# 2398 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 429 "src/frontc/cparser.mly"
                                                                                   (
    checkConnective(fst _5);
    EXPRTRANSFORMER(fst _3, fst _7, _1)
  )
# 2415 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 433 "src/frontc/cparser.mly"
                           ( PRAGMA (VARIABLE "parse_error", _1) )
# 2423 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 437 "src/frontc/cparser.mly"
             (fst _1)
# 2430 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 438 "src/frontc/cparser.mly"
                  (fst _1)
# 2437 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 439 "src/frontc/cparser.mly"
                                        ( "@name(" ^ fst _3 ^ ")" )
# 2445 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    Obj.repr(
# 443 "src/frontc/cparser.mly"
                                        ( () )
# 2451 "src/frontc/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    Obj.repr(
# 444 "src/frontc/cparser.mly"
                                        ( () )
# 2457 "src/frontc/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 451 "src/frontc/cparser.mly"
          (VARIABLE (fst _1), snd _1)
# 2464 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.constant * cabsloc) in
    Obj.repr(
# 453 "src/frontc/cparser.mly"
          (CONSTANT (fst _1), snd _1)
# 2471 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 455 "src/frontc/cparser.mly"
          (smooth_expression (fst _1), snd _1)
# 2478 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 457 "src/frontc/cparser.mly"
          ( GNU_BODY (fst3 _2), _1 )
# 2486 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 461 "src/frontc/cparser.mly"
                         ( EXPR_PATTERN(fst _3), _1 )
# 2495 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_expression) in
    Obj.repr(
# 466 "src/frontc/cparser.mly"
                        ( _1 )
# 2502 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 468 "src/frontc/cparser.mly"
   (INDEX (fst _1, smooth_expression _2), snd _1)
# 2510 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 470 "src/frontc/cparser.mly"
   (CALL (fst _1, _3), snd _1)
# 2519 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 472 "src/frontc/cparser.mly"
                        ( let b, d = _5 in
                          CALL (VARIABLE "__builtin_va_arg", 
                                [fst _3; TYPE_SIZEOF (b, d)]), _1 )
# 2531 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 476 "src/frontc/cparser.mly"
                        ( let b1,d1 = _3 in
                          let b2,d2 = _5 in
                          CALL (VARIABLE "__builtin_types_compatible_p", 
                                [TYPE_SIZEOF(b1,d1); TYPE_SIZEOF(b2,d2)]), _1 )
# 2544 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    Obj.repr(
# 481 "src/frontc/cparser.mly"
                        ( transformOffsetOf _3 (fst _5), _1 )
# 2554 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 483 "src/frontc/cparser.mly"
          (MEMBEROF (fst _1, _3), snd _1)
# 2562 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 485 "src/frontc/cparser.mly"
          (MEMBEROFPTR (fst _1, _3), snd _1)
# 2570 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 487 "src/frontc/cparser.mly"
          (UNARY (POSINCR, fst _1), snd _1)
# 2578 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 489 "src/frontc/cparser.mly"
          (UNARY (POSDECR, fst _1), snd _1)
# 2586 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 492 "src/frontc/cparser.mly"
          ( CAST(_2, COMPOUND_INIT _5), _1 )
# 2597 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 497 "src/frontc/cparser.mly"
          ( VARIABLE (fst _1), snd _1 )
# 2604 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'offsetof_member_designator) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 499 "src/frontc/cparser.mly"
   ( MEMBEROF (fst _1, fst _3), snd _1 )
# 2612 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 501 "src/frontc/cparser.mly"
   ( INDEX (fst _1, smooth_expression _2), snd _1 )
# 2620 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 506 "src/frontc/cparser.mly"
                        ( _1 )
# 2627 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 508 "src/frontc/cparser.mly"
          (UNARY (PREINCR, fst _2), _1)
# 2635 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 510 "src/frontc/cparser.mly"
          (UNARY (PREDECR, fst _2), _1)
# 2643 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 512 "src/frontc/cparser.mly"
          (EXPR_SIZEOF (fst _2), _1)
# 2651 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 514 "src/frontc/cparser.mly"
          (let b, d = _3 in TYPE_SIZEOF (b, d), _1)
# 2660 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 516 "src/frontc/cparser.mly"
          (EXPR_ALIGNOF (fst _2), _1)
# 2668 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 518 "src/frontc/cparser.mly"
          (let b, d = _3 in TYPE_ALIGNOF (b, d), _1)
# 2677 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 520 "src/frontc/cparser.mly"
          (UNARY (PLUS, fst _2), _1)
# 2685 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 522 "src/frontc/cparser.mly"
          (UNARY (MINUS, fst _2), _1)
# 2693 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 524 "src/frontc/cparser.mly"
          (UNARY (MEMOF, fst _2), _1)
# 2701 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 526 "src/frontc/cparser.mly"
          (UNARY (ADDROF, fst _2), _1)
# 2709 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 528 "src/frontc/cparser.mly"
          (UNARY (NOT, fst _2), _1)
# 2717 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 530 "src/frontc/cparser.mly"
          (UNARY (BNOT, fst _2), _1)
# 2725 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 531 "src/frontc/cparser.mly"
                               ( LABELADDR (fst _2), _1 )
# 2733 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 536 "src/frontc/cparser.mly"
                         ( _1 )
# 2740 "src/frontc/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 538 "src/frontc/cparser.mly"
           ( CAST(_2, SINGLE_INIT (fst _4)), _1 )
# 2749 "src/frontc/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 543 "src/frontc/cparser.mly"
                         ( _1 )
# 2756 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 545 "src/frontc/cparser.mly"
   (BINARY(MUL, fst _1, fst _3), snd _1)
# 2765 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 547 "src/frontc/cparser.mly"
   (BINARY(DIV, fst _1, fst _3), snd _1)
# 2773 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 549 "src/frontc/cparser.mly"
   (BINARY(MOD, fst _1, fst _3), snd _1)
# 2781 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 554 "src/frontc/cparser.mly"
                        ( _1 )
# 2788 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 556 "src/frontc/cparser.mly"
   (BINARY(ADD, fst _1, fst _3), snd _1)
# 2797 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 558 "src/frontc/cparser.mly"
   (BINARY(SUB, fst _1, fst _3), snd _1)
# 2806 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 563 "src/frontc/cparser.mly"
                         ( _1 )
# 2813 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 565 "src/frontc/cparser.mly"
   (BINARY(SHL, fst _1, fst _3), snd _1)
# 2821 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 567 "src/frontc/cparser.mly"
   (BINARY(SHR, fst _1, fst _3), snd _1)
# 2829 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 573 "src/frontc/cparser.mly"
                        ( _1 )
# 2836 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 575 "src/frontc/cparser.mly"
   (BINARY(LT, fst _1, fst _3), snd _1)
# 2844 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 577 "src/frontc/cparser.mly"
   (BINARY(GT, fst _1, fst _3), snd _1)
# 2852 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 579 "src/frontc/cparser.mly"
   (BINARY(LE, fst _1, fst _3), snd _1)
# 2860 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 581 "src/frontc/cparser.mly"
   (BINARY(GE, fst _1, fst _3), snd _1)
# 2868 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 586 "src/frontc/cparser.mly"
                        ( _1 )
# 2875 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 588 "src/frontc/cparser.mly"
   (BINARY(EQ, fst _1, fst _3), snd _1)
# 2883 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 590 "src/frontc/cparser.mly"
   (BINARY(NE, fst _1, fst _3), snd _1)
# 2891 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 596 "src/frontc/cparser.mly"
                       ( _1 )
# 2898 "src/frontc/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 598 "src/frontc/cparser.mly"
   (BINARY(BAND, fst _1, fst _3), snd _1)
# 2907 "src/frontc/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 603 "src/frontc/cparser.mly"
                       ( _1 )
# 2914 "src/frontc/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 605 "src/frontc/cparser.mly"
   (BINARY(XOR, fst _1, fst _3), snd _1)
# 2922 "src/frontc/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 610 "src/frontc/cparser.mly"
                        ( _1 )
# 2929 "src/frontc/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 612 "src/frontc/cparser.mly"
   (BINARY(BOR, fst _1, fst _3), snd _1)
# 2937 "src/frontc/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 617 "src/frontc/cparser.mly"
                        ( _1 )
# 2944 "src/frontc/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 619 "src/frontc/cparser.mly"
   (BINARY(AND, fst _1, fst _3), snd _1)
# 2953 "src/frontc/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 624 "src/frontc/cparser.mly"
                        ( _1 )
# 2960 "src/frontc/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 626 "src/frontc/cparser.mly"
   (BINARY(OR, fst _1, fst _3), snd _1)
# 2968 "src/frontc/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_expression) in
    Obj.repr(
# 631 "src/frontc/cparser.mly"
                         ( _1 )
# 2975 "src/frontc/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 633 "src/frontc/cparser.mly"
   (QUESTION (fst _1, _3, fst _5), snd _1)
# 2984 "src/frontc/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 641 "src/frontc/cparser.mly"
                         ( _1 )
# 2991 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 643 "src/frontc/cparser.mly"
   (BINARY(ASSIGN, fst _1, fst _3), snd _1)
# 2999 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 645 "src/frontc/cparser.mly"
   (BINARY(ADD_ASSIGN, fst _1, fst _3), snd _1)
# 3007 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 647 "src/frontc/cparser.mly"
   (BINARY(SUB_ASSIGN, fst _1, fst _3), snd _1)
# 3015 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 649 "src/frontc/cparser.mly"
   (BINARY(MUL_ASSIGN, fst _1, fst _3), snd _1)
# 3023 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 651 "src/frontc/cparser.mly"
   (BINARY(DIV_ASSIGN, fst _1, fst _3), snd _1)
# 3031 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 653 "src/frontc/cparser.mly"
   (BINARY(MOD_ASSIGN, fst _1, fst _3), snd _1)
# 3039 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 655 "src/frontc/cparser.mly"
   (BINARY(BAND_ASSIGN, fst _1, fst _3), snd _1)
# 3047 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 657 "src/frontc/cparser.mly"
   (BINARY(BOR_ASSIGN, fst _1, fst _3), snd _1)
# 3055 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 659 "src/frontc/cparser.mly"
   (BINARY(XOR_ASSIGN, fst _1, fst _3), snd _1)
# 3063 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 661 "src/frontc/cparser.mly"
   (BINARY(SHL_ASSIGN, fst _1, fst _3), snd _1)
# 3071 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 663 "src/frontc/cparser.mly"
   (BINARY(SHR_ASSIGN, fst _1, fst _3), snd _1)
# 3079 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 668 "src/frontc/cparser.mly"
                        ( _1 )
# 3086 "src/frontc/cparser.ml"
               : Cabs.expression * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 673 "src/frontc/cparser.mly"
               (CONST_INT (fst _1), snd _1)
# 3093 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 674 "src/frontc/cparser.mly"
                 (CONST_FLOAT (fst _1), snd _1)
# 3100 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 675 "src/frontc/cparser.mly"
                (CONST_CHAR (fst _1), snd _1)
# 3107 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 676 "src/frontc/cparser.mly"
                 (CONST_WCHAR (fst _1), snd _1)
# 3114 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 677 "src/frontc/cparser.mly"
                             (CONST_STRING (fst _1), snd _1)
# 3121 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * cabsloc) in
    Obj.repr(
# 678 "src/frontc/cparser.mly"
                   (CONST_WSTRING (fst _1), snd _1)
# 3128 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list Queue.t * cabsloc) in
    Obj.repr(
# 684 "src/frontc/cparser.mly"
                                        (
     let queue, location = _1 in
     let buffer = Buffer.create (Queue.length queue) in
     Queue.iter
       (List.iter
	  (fun value ->
	    let char = int64_to_char value in
	    Buffer.add_char buffer char))
       queue;
     Buffer.contents buffer, location
   )
# 3145 "src/frontc/cparser.ml"
               : string * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 698 "src/frontc/cparser.mly"
                                        (intlist_to_string (fst _1) )
# 3152 "src/frontc/cparser.ml"
               : 'one_string_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 701 "src/frontc/cparser.mly"
                                        (
      let queue = Queue.create () in
      Queue.add (fst _1) queue;
      queue, snd _1
    )
# 3163 "src/frontc/cparser.ml"
               : int64 list Queue.t * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list Queue.t * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 706 "src/frontc/cparser.mly"
                                        (
      Queue.add (fst _2) (fst _1);
      _1
    )
# 3174 "src/frontc/cparser.ml"
               : int64 list Queue.t * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 713 "src/frontc/cparser.mly"
                                        ( _1 )
# 3181 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 714 "src/frontc/cparser.mly"
                                        ( (fst _1) @ (fst _2), snd _1 )
# 3189 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 715 "src/frontc/cparser.mly"
                                        ( (fst _1) @ (fst _2), snd _1 )
# 3197 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 720 "src/frontc/cparser.mly"
                  (_1)
# 3204 "src/frontc/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 721 "src/frontc/cparser.mly"
                                        ((Cabs.explodeStringToInts 
					    !currentFunctionName), _1)
# 3212 "src/frontc/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 723 "src/frontc/cparser.mly"
                                        ((Cabs.explodeStringToInts 
					    !currentFunctionName), _1)
# 3220 "src/frontc/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 728 "src/frontc/cparser.mly"
                        ( SINGLE_INIT (fst _1) )
# 3227 "src/frontc/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 730 "src/frontc/cparser.mly"
   ( COMPOUND_INIT _2)
# 3236 "src/frontc/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat * Cabs.init_expression) in
    Obj.repr(
# 733 "src/frontc/cparser.mly"
                                            ( [_1] )
# 3243 "src/frontc/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat * Cabs.init_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'initializer_list_opt) in
    Obj.repr(
# 734 "src/frontc/cparser.mly"
                                            ( _1 :: _3 )
# 3251 "src/frontc/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 737 "src/frontc/cparser.mly"
                                            ( [] )
# 3257 "src/frontc/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.initwhat * Cabs.init_expression) list) in
    Obj.repr(
# 738 "src/frontc/cparser.mly"
                                            ( _1 )
# 3264 "src/frontc/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'eq_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 741 "src/frontc/cparser.mly"
                                            ( (_1, _3) )
# 3273 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gcc_init_designators) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 742 "src/frontc/cparser.mly"
                                         ( (_1, _2) )
# 3281 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 743 "src/frontc/cparser.mly"
                                        ( (NEXT_INIT, _1) )
# 3288 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    Obj.repr(
# 746 "src/frontc/cparser.mly"
                             ( () )
# 3294 "src/frontc/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 748 "src/frontc/cparser.mly"
                                 ( () )
# 3300 "src/frontc/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 751 "src/frontc/cparser.mly"
                                                 ( INFIELD_INIT(_2, _3) )
# 3308 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 753 "src/frontc/cparser.mly"
                                        ( ATINDEX_INIT(fst _2, _4) )
# 3316 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 755 "src/frontc/cparser.mly"
                                        ( ATINDEXRANGE_INIT(fst _2, fst _4) )
# 3324 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    Obj.repr(
# 758 "src/frontc/cparser.mly"
                                        ( NEXT_INIT )
# 3330 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 759 "src/frontc/cparser.mly"
                                        ( _1 )
# 3337 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    Obj.repr(
# 763 "src/frontc/cparser.mly"
                                        ( INFIELD_INIT(_1, NEXT_INIT) )
# 3344 "src/frontc/cparser.ml"
               : 'gcc_init_designators))
; (fun __caml_parser_env ->
    Obj.repr(
# 767 "src/frontc/cparser.mly"
                                    ( [] )
# 3350 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 768 "src/frontc/cparser.mly"
                                    ( fst _1 )
# 3357 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 773 "src/frontc/cparser.mly"
          (NOTHING)
# 3363 "src/frontc/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 775 "src/frontc/cparser.mly"
          (smooth_expression (fst _1))
# 3370 "src/frontc/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 779 "src/frontc/cparser.mly"
                                           ([fst _1], snd _1)
# 3377 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 780 "src/frontc/cparser.mly"
                                                  ( fst _1 :: fst _3, snd _1 )
# 3385 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 781 "src/frontc/cparser.mly"
                                                  ( _3 )
# 3392 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 785 "src/frontc/cparser.mly"
                                    ( NOTHING )
# 3398 "src/frontc/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 786 "src/frontc/cparser.mly"
                                    ( smooth_expression (fst _1) )
# 3405 "src/frontc/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 790 "src/frontc/cparser.mly"
                                                   ( _2 )
# 3413 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 791 "src/frontc/cparser.mly"
                                                   ( [], _1 )
# 3420 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 795 "src/frontc/cparser.mly"
                                                       ( fst _2 )
# 3427 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 796 "src/frontc/cparser.mly"
                                                       ( [] )
# 3433 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'block_begin) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'block_attrs) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.statement list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 803 "src/frontc/cparser.mly"
                                         (!Lexerhack.pop_context();
                                          { blabels = _2;
                                            battrs = _3;
                                            bstmts = _4 },
					    _1, _5
                                         )
# 3449 "src/frontc/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 809 "src/frontc/cparser.mly"
                                         ( { blabels = [];
                                             battrs  = [];
                                             bstmts  = [] },
					     _2, _3
                                         )
# 3461 "src/frontc/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 816 "src/frontc/cparser.mly"
                           (!Lexerhack.push_context (); _1)
# 3468 "src/frontc/cparser.ml"
               : 'block_begin))
; (fun __caml_parser_env ->
    Obj.repr(
# 820 "src/frontc/cparser.mly"
                                                            ( [] )
# 3474 "src/frontc/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 822 "src/frontc/cparser.mly"
                                        ( [("__blockattribute__", _2)] )
# 3481 "src/frontc/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    Obj.repr(
# 827 "src/frontc/cparser.mly"
                                         ( [] )
# 3487 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 828 "src/frontc/cparser.mly"
                                         ( DEFINITION(_1) :: _2 )
# 3495 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.statement) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 829 "src/frontc/cparser.mly"
                                         ( _1 :: _2 )
# 3503 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 831 "src/frontc/cparser.mly"
                                         ( [ LABEL (fst _1, NOP (snd _1), 
                                                    snd _1)] )
# 3511 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    Obj.repr(
# 836 "src/frontc/cparser.mly"
                                                     ( [] )
# 3517 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 837 "src/frontc/cparser.mly"
                                                     ( _2 @ _4 )
# 3526 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 840 "src/frontc/cparser.mly"
                                         ( [ fst _1 ] )
# 3533 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 841 "src/frontc/cparser.mly"
                                         ( fst _1 :: _3 )
# 3541 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 847 "src/frontc/cparser.mly"
               (NOP _1 )
# 3548 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 849 "src/frontc/cparser.mly"
          (COMPUTATION (smooth_expression (fst _1), snd _1))
# 3556 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 850 "src/frontc/cparser.mly"
                        (BLOCK (fst3 _1, snd3 _1))
# 3563 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 852 "src/frontc/cparser.mly"
                 (IF (smooth_expression (fst _2), _3, NOP _1, _1))
# 3572 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.statement) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 854 "src/frontc/cparser.mly"
                 (IF (smooth_expression (fst _2), _3, _5, _1))
# 3582 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 856 "src/frontc/cparser.mly"
                        (SWITCH (smooth_expression (fst _2), _3, _1))
# 3591 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 858 "src/frontc/cparser.mly"
          (WHILE (smooth_expression (fst _2), _3, _1))
# 3600 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.statement) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 860 "src/frontc/cparser.mly"
                   (DOWHILE (smooth_expression (fst _4), _2, _1))
# 3611 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : 'for_clause) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 863 "src/frontc/cparser.mly"
                          (FOR (_3, _4, _6, _8, _1))
# 3624 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement) in
    Obj.repr(
# 865 "src/frontc/cparser.mly"
                   (LABEL (fst _1, _3, snd _1))
# 3632 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 867 "src/frontc/cparser.mly"
                          (CASE (fst _2, NOP _1, _1))
# 3640 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 869 "src/frontc/cparser.mly"
                          (CASERANGE (fst _2, fst _4, NOP _1, _1))
# 3649 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 871 "src/frontc/cparser.mly"
                          (DEFAULT (NOP _1, _1))
# 3656 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 872 "src/frontc/cparser.mly"
                       (RETURN (NOTHING, _1))
# 3664 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 874 "src/frontc/cparser.mly"
                          (RETURN (smooth_expression (fst _2), _1))
# 3673 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 875 "src/frontc/cparser.mly"
                        (BREAK _1)
# 3681 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 876 "src/frontc/cparser.mly"
                        (CONTINUE _1)
# 3689 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 878 "src/frontc/cparser.mly"
                   (GOTO (fst _2, _1))
# 3698 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 880 "src/frontc/cparser.mly"
                                 ( COMPGOTO (smooth_expression (fst _3), _1) )
# 3708 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'asmtemplate) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'asmoutputs) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 882 "src/frontc/cparser.mly"
                        ( ASM (_2, _4, _5, _1) )
# 3720 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 883 "src/frontc/cparser.mly"
                        ( ASM ([], [fst _1], None, snd _1))
# 3727 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 885 "src/frontc/cparser.mly"
                        ( let b, _, _ = _2 in
                          let h, _, _ = _5 in
                          if not !Cprint.msvcMode then 
                            parse_error "try/except in GCC code";
                          TRY_EXCEPT (b, COMMA (fst _4), h, _1) )
# 3742 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 891 "src/frontc/cparser.mly"
                        ( let b, _, _ = _2 in
                          let h, _, _ = _4 in
                          if not !Cprint.msvcMode then 
                            parse_error "try/finally in GCC code";
                          TRY_FINALLY (b, h, _1) )
# 3756 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 897 "src/frontc/cparser.mly"
                                 ( (NOP _2))
# 3764 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 902 "src/frontc/cparser.mly"
                                 ( FC_EXP _1 )
# 3772 "src/frontc/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 903 "src/frontc/cparser.mly"
                                 ( FC_DECL _1 )
# 3779 "src/frontc/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.init_name list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 908 "src/frontc/cparser.mly"
                                       ( doDeclaration (snd _1) (fst _1) _2 )
# 3788 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 909 "src/frontc/cparser.mly"
                                    ( doDeclaration (snd _1) (fst _1) [] )
# 3796 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name) in
    Obj.repr(
# 912 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 3803 "src/frontc/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.init_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name list) in
    Obj.repr(
# 913 "src/frontc/cparser.mly"
                                                 ( _1 :: _3 )
# 3811 "src/frontc/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 917 "src/frontc/cparser.mly"
                                        ( (_1, NO_INIT) )
# 3818 "src/frontc/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 919 "src/frontc/cparser.mly"
                                        ( (_1, _3) )
# 3826 "src/frontc/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 924 "src/frontc/cparser.mly"
                                        ( SpecTypedef :: _2, _1  )
# 3834 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 925 "src/frontc/cparser.mly"
                                        ( SpecStorage EXTERN :: _2, _1 )
# 3842 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 926 "src/frontc/cparser.mly"
                                        ( SpecStorage STATIC :: _2, _1 )
# 3850 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 927 "src/frontc/cparser.mly"
                                        ( SpecStorage AUTO :: _2, _1 )
# 3858 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 928 "src/frontc/cparser.mly"
                                        ( SpecStorage REGISTER :: _2, _1)
# 3866 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 930 "src/frontc/cparser.mly"
                                          ( SpecType (fst _1) :: _2, snd _1 )
# 3874 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 932 "src/frontc/cparser.mly"
                                        ( SpecInline :: _2, _1 )
# 3882 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 933 "src/frontc/cparser.mly"
                                        ( (fst _1) :: _2, snd _1 )
# 3890 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 934 "src/frontc/cparser.mly"
                                        ( SpecAttr (fst _1) :: _2, snd _1 )
# 3898 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 936 "src/frontc/cparser.mly"
                                        ( [ SpecPattern(fst _3) ], _1 )
# 3907 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 941 "src/frontc/cparser.mly"
                                        ( [] )
# 3913 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 942 "src/frontc/cparser.mly"
                                        ( fst _1 )
# 3920 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 949 "src/frontc/cparser.mly"
                                        ( [] )
# 3926 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 950 "src/frontc/cparser.mly"
                                        ( fst _1 )
# 3933 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 953 "src/frontc/cparser.mly"
                    ( Tvoid, _1)
# 3940 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 954 "src/frontc/cparser.mly"
                    ( Tchar, _1 )
# 3947 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 955 "src/frontc/cparser.mly"
                    ( Tshort, _1 )
# 3954 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 956 "src/frontc/cparser.mly"
                    ( Tint, _1 )
# 3961 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 957 "src/frontc/cparser.mly"
                    ( Tlong, _1 )
# 3968 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 958 "src/frontc/cparser.mly"
                    ( Tint64, _1 )
# 3975 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 959 "src/frontc/cparser.mly"
                    ( Tfloat, _1 )
# 3982 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 960 "src/frontc/cparser.mly"
                    ( Tdouble, _1 )
# 3989 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 961 "src/frontc/cparser.mly"
                    ( Tsigned, _1 )
# 3996 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 962 "src/frontc/cparser.mly"
                    ( Tunsigned, _1 )
# 4003 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 964 "src/frontc/cparser.mly"
                                                   ( Tstruct (_2, None,    []), _1 )
# 4011 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 966 "src/frontc/cparser.mly"
                                                   ( Tstruct (_2, Some _4, []), _1 )
# 4022 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 968 "src/frontc/cparser.mly"
                                                   ( Tstruct ("", Some _3, []), _1 )
# 4032 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 970 "src/frontc/cparser.mly"
                                                   ( Tstruct (_3, Some _5, _2), _1 )
# 4044 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 972 "src/frontc/cparser.mly"
                                                   ( Tstruct ("", Some _4, _2), _1 )
# 4055 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 974 "src/frontc/cparser.mly"
                                                   ( Tunion  (_2, None,    []), _1 )
# 4063 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 976 "src/frontc/cparser.mly"
                                                   ( Tunion  (_2, Some _4, []), _1 )
# 4074 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 978 "src/frontc/cparser.mly"
                                                   ( Tunion  ("", Some _3, []), _1 )
# 4084 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 980 "src/frontc/cparser.mly"
                                                   ( Tunion  (_3, Some _5, _2), _1 )
# 4096 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 982 "src/frontc/cparser.mly"
                                                   ( Tunion  ("", Some _4, _2), _1 )
# 4107 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 984 "src/frontc/cparser.mly"
                                                   ( Tenum   (_2, None,    []), _1 )
# 4115 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 986 "src/frontc/cparser.mly"
                                                   ( Tenum   (_2, Some _4, []), _1 )
# 4127 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 988 "src/frontc/cparser.mly"
                                                   ( Tenum   ("", Some _3, []), _1 )
# 4138 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 990 "src/frontc/cparser.mly"
                                                   ( Tenum   (_3, Some _5, _2), _1 )
# 4151 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 992 "src/frontc/cparser.mly"
                                                   ( Tenum   ("", Some _4, _2), _1 )
# 4163 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 993 "src/frontc/cparser.mly"
                    ( Tnamed (fst _1), snd _1 )
# 4170 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 994 "src/frontc/cparser.mly"
                                        ( TtypeofE (fst _3), _1 )
# 4179 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 995 "src/frontc/cparser.mly"
                                        ( let s, d = _3 in
                                          TtypeofT (s, d), _1 )
# 4189 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1001 "src/frontc/cparser.mly"
                                         ( [] )
# 4195 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1003 "src/frontc/cparser.mly"
                                         ( (fst _1, 
                                            [(missingFieldDecl, None)]) :: _3 )
# 4205 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1007 "src/frontc/cparser.mly"
                                         ( _2 )
# 4213 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : (Cabs.name * expression option) list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1009 "src/frontc/cparser.mly"
                                          ( (fst _1, _2) 
                                            :: _4 )
# 4224 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1012 "src/frontc/cparser.mly"
                                          ( _3 )
# 4232 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name * expression option) in
    Obj.repr(
# 1015 "src/frontc/cparser.mly"
                                         ( [_1] )
# 4239 "src/frontc/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name * expression option) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.name * expression option) list) in
    Obj.repr(
# 1016 "src/frontc/cparser.mly"
                                         ( _1 :: _3 )
# 4247 "src/frontc/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1019 "src/frontc/cparser.mly"
                                    ( (_1, None) )
# 4254 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1020 "src/frontc/cparser.mly"
                                    ( (_1, Some (fst _3)) )
# 4262 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1021 "src/frontc/cparser.mly"
                                    ( (missingFieldDecl, Some (fst _2)) )
# 4269 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1025 "src/frontc/cparser.mly"
                  ([_1])
# 4276 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1026 "src/frontc/cparser.mly"
                                       (_1 @ [_3])
# 4284 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    Obj.repr(
# 1027 "src/frontc/cparser.mly"
                                        ( _1 )
# 4291 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1030 "src/frontc/cparser.mly"
            ((fst _1, NOTHING, snd _1))
# 4298 "src/frontc/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1031 "src/frontc/cparser.mly"
                         ((fst _1, fst _3, snd _1))
# 4306 "src/frontc/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1037 "src/frontc/cparser.mly"
                                         ( let (n, decl) = _2 in
                                           (n, applyPointer (fst _1) decl, _3, snd _1) )
# 4316 "src/frontc/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1045 "src/frontc/cparser.mly"
                                   ( (_1, JUSTBASE) )
# 4323 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.name) in
    Obj.repr(
# 1048 "src/frontc/cparser.mly"
                                   ( let (n,decl,al,loc) = _3 in
                                     (n, PARENTYPE(_2,decl,al)) )
# 4333 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1052 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     (n, ARRAY(decl, _3, _4)) )
# 4343 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    Obj.repr(
# 1055 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     (n, ARRAY(decl, _3, NOTHING)) )
# 4352 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1058 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     (n, PROTO(decl, params, isva))
                                   )
# 4365 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1065 "src/frontc/cparser.mly"
                                   ( !Lexerhack.push_context () )
# 4372 "src/frontc/cparser.ml"
               : 'parameter_list_startscope))
; (fun __caml_parser_env ->
    Obj.repr(
# 1068 "src/frontc/cparser.mly"
                                   ( ([], false) )
# 4378 "src/frontc/cparser.ml"
               : 'rest_par_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1069 "src/frontc/cparser.mly"
                                   ( let (params, isva) = _2 in 
                                     (_1 :: params, isva) 
                                   )
# 4388 "src/frontc/cparser.ml"
               : 'rest_par_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1074 "src/frontc/cparser.mly"
                                        ( ([], false) )
# 4394 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    Obj.repr(
# 1075 "src/frontc/cparser.mly"
                                        ( ([], true) )
# 4400 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1076 "src/frontc/cparser.mly"
                                        ( let (params, isva) = _3 in 
                                          (_2 :: params, isva)
                                        )
# 4410 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1083 "src/frontc/cparser.mly"
                                          ( (fst _1, _2) )
# 4418 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1084 "src/frontc/cparser.mly"
                                          ( let d, a = _2 in
                                            (fst _1, ("", d, a, cabslu)) )
# 4427 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1086 "src/frontc/cparser.mly"
                                          ( (fst _1, ("", JUSTBASE, [], cabslu)) )
# 4434 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    Obj.repr(
# 1087 "src/frontc/cparser.mly"
                                          ( _2 )
# 4442 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'direct_old_proto_decl) in
    Obj.repr(
# 1092 "src/frontc/cparser.mly"
                                      ( let (n, decl, a) = _2 in
					  (n, applyPointer (fst _1) decl, a, snd _1) )
# 4451 "src/frontc/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1097 "src/frontc/cparser.mly"
                                   ( let par_decl, isva = doOldParDecl _3 _5 in
                                     let n, decl = _1 in
                                     (n, PROTO(decl, par_decl, isva), [])
                                   )
# 4464 "src/frontc/cparser.ml"
               : 'direct_old_proto_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1102 "src/frontc/cparser.mly"
                                   ( let n, decl = _1 in
                                     (n, PROTO(decl, [], false), [])
                                   )
# 4474 "src/frontc/cparser.ml"
               : 'direct_old_proto_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1108 "src/frontc/cparser.mly"
                                               ( [fst _1] )
# 4481 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 1109 "src/frontc/cparser.mly"
                                               ( let rest = _3 in
                                                 (fst _1 :: rest) )
# 4490 "src/frontc/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1114 "src/frontc/cparser.mly"
                                          ( ([], false) )
# 4496 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1116 "src/frontc/cparser.mly"
                                          ( ([(fst _1, _2)], true) )
# 4505 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1118 "src/frontc/cparser.mly"
                                          ( let rest, isva = _4 in
                                            ((fst _1, _2) :: rest, isva) 
                                          )
# 4517 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1124 "src/frontc/cparser.mly"
                                          ( [_1] )
# 4524 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef) in
    Obj.repr(
# 1125 "src/frontc/cparser.mly"
                                          ( _1 :: _3 )
# 4532 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    Obj.repr(
# 1126 "src/frontc/cparser.mly"
                                          ( [] )
# 4538 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1131 "src/frontc/cparser.mly"
                                ( _2 :: fst _3, _1 )
# 4547 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1134 "src/frontc/cparser.mly"
                                 ( [], currentLoc () )
# 4553 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1135 "src/frontc/cparser.mly"
                                 ( _1 )
# 4560 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1139 "src/frontc/cparser.mly"
                               ( let d, a = _2 in
                                 if a <> [] then begin
                                   parse_error "attributes in type name";
                                   raise Parsing.Parse_error
                                 end;
                                 (fst _1, d) 
                               )
# 4574 "src/frontc/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1146 "src/frontc/cparser.mly"
                               ( (fst _1, JUSTBASE) )
# 4581 "src/frontc/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1149 "src/frontc/cparser.mly"
                                          ( applyPointer (fst _1) _2, _3 )
# 4590 "src/frontc/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1150 "src/frontc/cparser.mly"
                                          ( applyPointer (fst _1) JUSTBASE, [] )
# 4597 "src/frontc/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1157 "src/frontc/cparser.mly"
                                   ( let d, a = _3 in
                                     PARENTYPE (_2, d, a)
                                   )
# 4608 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1162 "src/frontc/cparser.mly"
                                   ( JUSTBASE )
# 4615 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1165 "src/frontc/cparser.mly"
                                   ( ARRAY(_1, [], _3) )
# 4623 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1168 "src/frontc/cparser.mly"
                                   ( let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     PROTO (_1, params, isva)
                                   )
# 4635 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type) in
    Obj.repr(
# 1174 "src/frontc/cparser.mly"
                                    ( _1 )
# 4642 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1175 "src/frontc/cparser.mly"
                                    ( JUSTBASE )
# 4648 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : cabsloc * spec_elem list * name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1179 "src/frontc/cparser.mly"
          ( let (loc, specs, decl) = _1 in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by 
                                    * announceFunctionName *)
            doFunctionDef loc (trd3 _2) specs decl (fst3 _2)
          )
# 4661 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1189 "src/frontc/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 4671 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1195 "src/frontc/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 4681 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1200 "src/frontc/cparser.mly"
                           ( let (params, isva) = _3 in
                             let fdec = 
                               (fst _1, PROTO(JUSTBASE, params, isva), [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec)
                           )
# 4697 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1211 "src/frontc/cparser.mly"
                           ( (* Convert pardecl to new style *)
                             let pardecl, isva = doOldParDecl _3 _5 in
                             (* Make the function declarator *)
                             let fdec = (fst _1,
                                         PROTO(JUSTBASE, pardecl,isva), 
                                         [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec) 
                            )
# 4717 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1224 "src/frontc/cparser.mly"
                           ( (* Make the function declarator *)
                             let fdec = (fst _1,
                                         PROTO(JUSTBASE, [], false), 
                                         [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec)
                            )
# 4733 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1237 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_CONST), _1 )
# 4740 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1238 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_VOLATILE), _1 )
# 4747 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1239 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_RESTRICT), _1 )
# 4754 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1244 "src/frontc/cparser.mly"
                   ( [])
# 4760 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1245 "src/frontc/cparser.mly"
                                 ( fst _1 :: _2 )
# 4768 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1251 "src/frontc/cparser.mly"
                                        ( [] )
# 4774 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1252 "src/frontc/cparser.mly"
                                        ( fst _1 :: _2 )
# 4782 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1254 "src/frontc/cparser.mly"
                                        ( ("__asm__", 
					   [CONSTANT(CONST_STRING (fst _3))]) :: _5 )
# 4793 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list_ne) in
    Obj.repr(
# 1261 "src/frontc/cparser.mly"
                                        ( ("__attribute__", _3), _1 )
# 4802 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1266 "src/frontc/cparser.mly"
                                        ( ("__declspec", _2), _1 )
# 4810 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1267 "src/frontc/cparser.mly"
                                        ( (fst _1, []), snd _1 )
# 4817 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1269 "src/frontc/cparser.mly"
                                        ( ("__thread",[]), _1 )
# 4824 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1274 "src/frontc/cparser.mly"
                                        ( _1 )
# 4831 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1275 "src/frontc/cparser.mly"
                                        ( ("const", []), _1 )
# 4838 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1276 "src/frontc/cparser.mly"
                                        ( ("restrict",[]), _1 )
# 4845 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1277 "src/frontc/cparser.mly"
                                        ( ("volatile",[]), _1 )
# 4852 "src/frontc/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list_ne) in
    Obj.repr(
# 1285 "src/frontc/cparser.mly"
                                        ( ("__attribute__", _3) )
# 4861 "src/frontc/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1286 "src/frontc/cparser.mly"
                                        ( ("__declspec", _2) )
# 4869 "src/frontc/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'just_attribute) in
    Obj.repr(
# 1292 "src/frontc/cparser.mly"
                                        ( [_1] )
# 4876 "src/frontc/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'just_attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'just_attributes) in
    Obj.repr(
# 1293 "src/frontc/cparser.mly"
                                        ( _1 :: _2 )
# 4884 "src/frontc/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1300 "src/frontc/cparser.mly"
             ( VARIABLE (fst _1) )
# 4891 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1302 "src/frontc/cparser.mly"
                  ( VARIABLE (fst _1) )
# 4898 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1303 "src/frontc/cparser.mly"
                                        ( _2 )
# 4906 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1304 "src/frontc/cparser.mly"
                                         ( CALL(VARIABLE (fst _1), [VARIABLE (fst _2)]) )
# 4914 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1305 "src/frontc/cparser.mly"
                                         ( CONSTANT(CONST_INT (fst _1)) )
# 4921 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1306 "src/frontc/cparser.mly"
                                         ( CONSTANT(CONST_STRING (fst _1)) )
# 4928 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1310 "src/frontc/cparser.mly"
                                         ( VARIABLE "aconst" )
# 4935 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1311 "src/frontc/cparser.mly"
                                         ( VARIABLE (fst _1 ^ ":" ^ fst _3) )
# 4943 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1313 "src/frontc/cparser.mly"
                                         ( VARIABLE (fst _1 ^ ":" ^ fst _3) )
# 4951 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1314 "src/frontc/cparser.mly"
                                         ( VARIABLE ("default:" ^ fst _3) )
# 4959 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1319 "src/frontc/cparser.mly"
                                         ( VARIABLE ("__noreturn__") )
# 4966 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_attr) in
    Obj.repr(
# 1323 "src/frontc/cparser.mly"
                                         ( _1 )
# 4973 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1326 "src/frontc/cparser.mly"
                                         ( CALL(VARIABLE (fst _1), [VARIABLE ""]) )
# 4981 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1327 "src/frontc/cparser.mly"
                                         ( CALL(VARIABLE (fst _1), _2) )
# 4989 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1329 "src/frontc/cparser.mly"
                                         (MEMBEROFPTR (_1, _3))
# 4997 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1330 "src/frontc/cparser.mly"
                                         (MEMBEROF (_1, _3))
# 5005 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_attr) in
    Obj.repr(
# 1337 "src/frontc/cparser.mly"
                                         ( _1 )
# 5012 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1338 "src/frontc/cparser.mly"
                                         (EXPR_SIZEOF (fst _2) )
# 5020 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1340 "src/frontc/cparser.mly"
                           (let b, d = _3 in TYPE_SIZEOF (b, d))
# 5029 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1342 "src/frontc/cparser.mly"
                                         (EXPR_ALIGNOF (fst _2) )
# 5037 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1343 "src/frontc/cparser.mly"
                                         (let b, d = _3 in TYPE_ALIGNOF (b, d))
# 5046 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1344 "src/frontc/cparser.mly"
                                        (UNARY (PLUS, _2))
# 5054 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1345 "src/frontc/cparser.mly"
                                        (UNARY (MINUS, _2))
# 5062 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1346 "src/frontc/cparser.mly"
                            (UNARY (MEMOF, _2))
# 5070 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1348 "src/frontc/cparser.mly"
                                 (UNARY (ADDROF, _2))
# 5078 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1349 "src/frontc/cparser.mly"
                                 (UNARY (NOT, _2))
# 5086 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1350 "src/frontc/cparser.mly"
                                        (UNARY (BNOT, _2))
# 5094 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_attr) in
    Obj.repr(
# 1354 "src/frontc/cparser.mly"
                                         ( _1 )
# 5101 "src/frontc/cparser.ml"
               : 'cast_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1358 "src/frontc/cparser.mly"
                                        ( _1 )
# 5108 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1359 "src/frontc/cparser.mly"
                                        (BINARY(MUL ,_1 , _3))
# 5117 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1360 "src/frontc/cparser.mly"
                                          (BINARY(DIV ,_1 , _3))
# 5125 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1361 "src/frontc/cparser.mly"
                                          (BINARY(MOD ,_1 , _3))
# 5133 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1366 "src/frontc/cparser.mly"
                                        ( _1 )
# 5140 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1367 "src/frontc/cparser.mly"
                                            (BINARY(ADD ,_1 , _3))
# 5149 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1368 "src/frontc/cparser.mly"
                                            (BINARY(SUB ,_1 , _3))
# 5158 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1372 "src/frontc/cparser.mly"
                                        ( _1 )
# 5165 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1373 "src/frontc/cparser.mly"
                                     (BINARY(SHL ,_1 , _3))
# 5173 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1374 "src/frontc/cparser.mly"
                                     (BINARY(SHR ,_1 , _3))
# 5181 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1378 "src/frontc/cparser.mly"
                                        ( _1 )
# 5188 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1379 "src/frontc/cparser.mly"
                                   (BINARY(LT ,_1 , _3))
# 5196 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1380 "src/frontc/cparser.mly"
                                   (BINARY(GT ,_1 , _3))
# 5204 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1381 "src/frontc/cparser.mly"
                                      (BINARY(LE ,_1 , _3))
# 5212 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1382 "src/frontc/cparser.mly"
                                      (BINARY(GE ,_1 , _3))
# 5220 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1386 "src/frontc/cparser.mly"
                                        ( _1 )
# 5227 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1387 "src/frontc/cparser.mly"
                                            (BINARY(EQ ,_1 , _3))
# 5235 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1388 "src/frontc/cparser.mly"
                                            (BINARY(NE ,_1 , _3))
# 5243 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1393 "src/frontc/cparser.mly"
                                        ( _1 )
# 5250 "src/frontc/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1394 "src/frontc/cparser.mly"
                                       (BINARY(BAND ,_1 , _3))
# 5259 "src/frontc/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1398 "src/frontc/cparser.mly"
                                           ( _1 )
# 5266 "src/frontc/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1399 "src/frontc/cparser.mly"
                                           (BINARY(XOR ,_1 , _3))
# 5274 "src/frontc/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1403 "src/frontc/cparser.mly"
                                          ( _1 )
# 5281 "src/frontc/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1404 "src/frontc/cparser.mly"
                                          (BINARY(BOR ,_1 , _3))
# 5289 "src/frontc/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1408 "src/frontc/cparser.mly"
                                                ( _1 )
# 5296 "src/frontc/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1409 "src/frontc/cparser.mly"
                                             (BINARY(AND ,_1 , _3))
# 5305 "src/frontc/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1413 "src/frontc/cparser.mly"
                                               ( _1 )
# 5312 "src/frontc/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1414 "src/frontc/cparser.mly"
                                               (BINARY(OR ,_1 , _3))
# 5320 "src/frontc/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_attr) in
    Obj.repr(
# 1418 "src/frontc/cparser.mly"
                                         ( _1 )
# 5327 "src/frontc/cparser.ml"
               : 'attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr) in
    Obj.repr(
# 1422 "src/frontc/cparser.mly"
                                         ( [_1] )
# 5334 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1423 "src/frontc/cparser.mly"
                                         ( _1 :: _3 )
# 5342 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1424 "src/frontc/cparser.mly"
                                         ( _3 )
# 5349 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list_ne) in
    Obj.repr(
# 1427 "src/frontc/cparser.mly"
                                         ( _2 )
# 5357 "src/frontc/cparser.ml"
               : 'paren_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1428 "src/frontc/cparser.mly"
                                         ( [] )
# 5364 "src/frontc/cparser.ml"
               : 'paren_attr_list_ne))
; (fun __caml_parser_env ->
    Obj.repr(
# 1432 "src/frontc/cparser.mly"
                                        ( [] )
# 5370 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1433 "src/frontc/cparser.mly"
                                        ( ("volatile", []) :: _2 )
# 5378 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1434 "src/frontc/cparser.mly"
                                        ( ("const", []) :: _2 )
# 5386 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string_constant) in
    Obj.repr(
# 1437 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 5393 "src/frontc/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'one_string_constant) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmtemplate) in
    Obj.repr(
# 1438 "src/frontc/cparser.mly"
                                                 ( _1 :: _2 )
# 5401 "src/frontc/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    Obj.repr(
# 1441 "src/frontc/cparser.mly"
                        ( None )
# 5407 "src/frontc/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asminputs) in
    Obj.repr(
# 1443 "src/frontc/cparser.mly"
                        ( let (ins, clobs) = _3 in
                          Some {aoutputs = _2; ainputs = ins; aclobbers = clobs} )
# 5416 "src/frontc/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1447 "src/frontc/cparser.mly"
                                        ( [] )
# 5422 "src/frontc/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperandsne) in
    Obj.repr(
# 1448 "src/frontc/cparser.mly"
                                        ( List.rev _1 )
# 5429 "src/frontc/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1451 "src/frontc/cparser.mly"
                                        ( [_1] )
# 5436 "src/frontc/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'asmoperandsne) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1452 "src/frontc/cparser.mly"
                                        ( _3 :: _1 )
# 5444 "src/frontc/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1455 "src/frontc/cparser.mly"
                                                 ( (fst _1, fst _3) )
# 5453 "src/frontc/cparser.ml"
               : 'asmoperand))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1456 "src/frontc/cparser.mly"
                                                 ( (fst _1, NOTHING ) )
# 5461 "src/frontc/cparser.ml"
               : 'asmoperand))
; (fun __caml_parser_env ->
    Obj.repr(
# 1459 "src/frontc/cparser.mly"
                             ( ([], []) )
# 5467 "src/frontc/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmclobber) in
    Obj.repr(
# 1461 "src/frontc/cparser.mly"
                        ( (_2, _3) )
# 5475 "src/frontc/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1464 "src/frontc/cparser.mly"
                                        ( [] )
# 5481 "src/frontc/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1465 "src/frontc/cparser.mly"
                                        ( _2 )
# 5488 "src/frontc/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string_constant) in
    Obj.repr(
# 1468 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 5495 "src/frontc/cparser.ml"
               : 'asmcloberlst_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'one_string_constant) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1469 "src/frontc/cparser.mly"
                                                 ( _1 :: _3 )
# 5503 "src/frontc/cparser.ml"
               : 'asmcloberlst_ne))
(* Entry interpret *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let interpret (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Cabs.definition list)
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 2 lexfun lexbuf : Cabs.definition list)
;;
# 1473 "src/frontc/cparser.mly"



# 5536 "src/frontc/cparser.ml"
